/*
 * This file is a part of VyQChat.
 *
 * Copyright (C) 2002-2004 Pawel Stolowski <yogin@linux.bydg.org>
 *
 * VyQChat is free software; you can redestribute it and/or modify it
 * under terms of GNU General Public License by Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY. See GPL for more details.
 */

#include "about.h"
#include "global.h"
#include <qlayout.h>
#include <qlabel.h>
#include <qpushbutton.h>
#include <qpixmap.h>

/* XPM photo */
static char * foto_xpm[] = {/*{{{*/
"105 120 4561 2",
"  	c None",
". 	c #FFFFFF",
"+ 	c #FFFFFE",
"@ 	c #FDFBF7",
"# 	c #FFFEF6",
"$ 	c #FFFEF7",
"% 	c #FFFEFA",
"& 	c #FEFDFC",
"* 	c #FCFDFA",
"= 	c #E4DCD6",
"- 	c #DDDAD1",
"; 	c #FDF7EF",
"> 	c #FCFAF9",
", 	c #F3F3F2",
"' 	c #F2F0EC",
") 	c #A4A5A3",
"! 	c #6C6B60",
"~ 	c #818483",
"{ 	c #B9BDAB",
"] 	c #CCC2B6",
"^ 	c #B8B2A5",
"/ 	c #5B5C57",
"( 	c #615D50",
"_ 	c #746E5D",
": 	c #A2A193",
"< 	c #DEDCDA",
"[ 	c #FFFFFC",
"} 	c #FFFEF3",
"| 	c #FAF7F8",
"1 	c #E0D7CB",
"2 	c #C9BC9F",
"3 	c #A89580",
"4 	c #8D806F",
"5 	c #63584D",
"6 	c #382C25",
"7 	c #322520",
"8 	c #2F2520",
"9 	c #3F3732",
"0 	c #47403C",
"a 	c #3C2D25",
"b 	c #33251E",
"c 	c #32241D",
"d 	c #3B2C24",
"e 	c #42342A",
"f 	c #4A4138",
"g 	c #979C9B",
"h 	c #A5A7A9",
"i 	c #DEE4E6",
"j 	c #F5F3E5",
"k 	c #FFFEFF",
"l 	c #FFFCF9",
"m 	c #F8E8D5",
"n 	c #CEB59A",
"o 	c #9F957D",
"p 	c #5C5147",
"q 	c #41352B",
"r 	c #403025",
"s 	c #3B2C22",
"t 	c #2E201B",
"u 	c #30201B",
"v 	c #2F211C",
"w 	c #2F221C",
"x 	c #2D1E19",
"y 	c #30221B",
"z 	c #2C1D18",
"A 	c #2E1F18",
"B 	c #2F201A",
"C 	c #34241D",
"D 	c #36291F",
"E 	c #392921",
"F 	c #352A26",
"G 	c #463E3B",
"H 	c #929399",
"I 	c #FBFCFD",
"J 	c #FCFBF9",
"K 	c #DEE5E3",
"L 	c #EFF5F6",
"M 	c #FFFEFC",
"N 	c #D6D2C7",
"O 	c #8C7D6A",
"P 	c #5B4B3D",
"Q 	c #3F2C23",
"R 	c #37251D",
"S 	c #32231C",
"T 	c #392B23",
"U 	c #33241C",
"V 	c #291915",
"W 	c #2E1E18",
"X 	c #2A1B16",
"Y 	c #291C18",
"Z 	c #2B1D18",
"` 	c #2A1A17",
" .	c #2B1C17",
"..	c #2F1E17",
"+.	c #2D1D18",
"@.	c #34231A",
"#.	c #2E1F19",
"$.	c #34251D",
"%.	c #342822",
"&.	c #7F7C80",
"*.	c #969485",
"=.	c #6F6450",
"-.	c #5F5245",
";.	c #9B958E",
">.	c #EBE1CF",
",.	c #F9F3E8",
"'.	c #EBE8E8",
").	c #91837B",
"!.	c #5C4533",
"~.	c #4A3527",
"{.	c #36261F",
"].	c #32221B",
"^.	c #2D1E18",
"/.	c #281916",
"(.	c #2D1E1A",
"_.	c #30211A",
":.	c #2A1A15",
"<.	c #2A1A16",
"[.	c #261814",
"}.	c #261815",
"|.	c #271815",
"1.	c #281915",
"2.	c #281914",
"3.	c #2D1D17",
"4.	c #2F1F18",
"5.	c #2C1C16",
"6.	c #301F17",
"7.	c #35241A",
"8.	c #32221C",
"9.	c #3F3128",
"0.	c #504839",
"a.	c #524032",
"b.	c #48372A",
"c.	c #88837E",
"d.	c #F5EADD",
"e.	c #FEEEDD",
"f.	c #FFFAF0",
"g.	c #FFFDFE",
"h.	c #D8D1D3",
"i.	c #6B5646",
"j.	c #59402E",
"k.	c #453125",
"l.	c #2F211B",
"m.	c #301E18",
"n.	c #2C1B16",
"o.	c #271714",
"p.	c #231312",
"q.	c #261714",
"r.	c #2A1915",
"s.	c #271813",
"t.	c #261614",
"u.	c #241613",
"v.	c #281814",
"w.	c #301F18",
"x.	c #2E1C16",
"y.	c #291914",
"z.	c #322018",
"A.	c #2A1913",
"B.	c #3A251A",
"C.	c #302018",
"D.	c #2F1E1B",
"E.	c #454037",
"F.	c #3B2F25",
"G.	c #3F2E24",
"H.	c #7C7473",
"I.	c #F5F1E8",
"J.	c #FFF3E7",
"K.	c #FFF6EE",
"L.	c #CECAC6",
"M.	c #634B39",
"N.	c #553E2E",
"O.	c #422F24",
"P.	c #36251D",
"Q.	c #37241C",
"R.	c #30201A",
"S.	c #2B1B16",
"T.	c #271713",
"U.	c #251613",
"V.	c #221311",
"W.	c #291A16",
"X.	c #291814",
"Y.	c #271613",
"Z.	c #261613",
"`.	c #2B1915",
" +	c #281813",
".+	c #251512",
"++	c #271814",
"@+	c #35221A",
"#+	c #2B1B15",
"$+	c #2E1D17",
"%+	c #311F18",
"&+	c #342018",
"*+	c #291916",
"=+	c #261915",
"-+	c #281C18",
";+	c #3E2E23",
">+	c #75696D",
",+	c #EDEBE3",
"'+	c #FFF5E1",
")+	c #FDF1D8",
"!+	c #FFFEFE",
"~+	c #FFFDFF",
"{+	c #C6C3C1",
"]+	c #634937",
"^+	c #5B422F",
"/+	c #453226",
"(+	c #38271E",
"_+	c #32201A",
":+	c #2F1E19",
"<+	c #2A1916",
"[+	c #231411",
"}+	c #241412",
"|+	c #2B1A15",
"1+	c #261512",
"2+	c #261612",
"3+	c #281713",
"4+	c #2D1C18",
"5+	c #301E19",
"6+	c #36221A",
"7+	c #2E1C17",
"8+	c #332018",
"9+	c #2D1C16",
"0+	c #301E17",
"a+	c #291D19",
"b+	c #443225",
"c+	c #5A4B49",
"d+	c #DDDFE4",
"e+	c #FEF4D5",
"f+	c #FCE8D6",
"g+	c #CDC4C5",
"h+	c #664A38",
"i+	c #5F4531",
"j+	c #443025",
"k+	c #38261E",
"l+	c #2F1F19",
"m+	c #34231B",
"n+	c #2B1916",
"o+	c #2D1B16",
"p+	c #251513",
"q+	c #2D1A15",
"r+	c #291813",
"s+	c #261715",
"t+	c #2F1E18",
"u+	c #301F1A",
"v+	c #2F1D17",
"w+	c #2E1B15",
"x+	c #241714",
"y+	c #33211A",
"z+	c #321F19",
"A+	c #2F1C17",
"B+	c #2A1914",
"C+	c #291A15",
"D+	c #281815",
"E+	c #30241F",
"F+	c #422F22",
"G+	c #4E403C",
"H+	c #DADCE1",
"I+	c #FCE8C9",
"J+	c #FDF6F2",
"K+	c #DED6D7",
"L+	c #694F3C",
"M+	c #5C4431",
"N+	c #462F25",
"O+	c #3E2A20",
"P+	c #37231D",
"Q+	c #36241D",
"R+	c #311E19",
"S+	c #2B1A16",
"T+	c #271614",
"U+	c #291713",
"V+	c #321F18",
"W+	c #332019",
"X+	c #322019",
"Y+	c #241411",
"Z+	c #37261D",
"`+	c #311F17",
" @	c #2D1C17",
".@	c #34261E",
"+@	c #3D2A20",
"@@	c #4C403C",
"#@	c #DFDEE0",
"$@	c #FEEADB",
"%@	c #EDE9EA",
"&@	c #78614F",
"*@	c #5F4633",
"=@	c #4F3628",
"-@	c #493123",
";@	c #3F2A1F",
">@	c #33201B",
",@	c #36231C",
"'@	c #311F19",
")@	c #2F1D18",
"!@	c #211211",
"~@	c #291714",
"{@	c #2A1714",
"]@	c #311E18",
"^@	c #31201A",
"/@	c #34211A",
"(@	c #2B1914",
"_@	c #301F19",
":@	c #2F1B16",
"<@	c #2D1B15",
"[@	c #31221C",
"}@	c #332119",
"|@	c #281B17",
"1@	c #3A261E",
"2@	c #5E534F",
"3@	c #EFECE8",
"4@	c #FFFDF7",
"5@	c #FFFCFF",
"6@	c #FFFBFF",
"7@	c #FDFCFC",
"8@	c #8A776C",
"9@	c #573F2F",
"0@	c #5B402E",
"a@	c #553A2A",
"b@	c #442F24",
"c@	c #37241D",
"d@	c #402A1F",
"e@	c #32201B",
"f@	c #2C1B17",
"g@	c #241311",
"h@	c #221210",
"i@	c #221211",
"j@	c #271512",
"k@	c #35211A",
"l@	c #31211B",
"m@	c #301E16",
"n@	c #35221B",
"o@	c #2B1B17",
"p@	c #231210",
"q@	c #34221B",
"r@	c #32211A",
"s@	c #3B281F",
"t@	c #3C2C21",
"u@	c #716363",
"v@	c #F4F4F5",
"w@	c #C4BCB8",
"x@	c #4A3429",
"y@	c #654B34",
"z@	c #5C4332",
"A@	c #52382A",
"B@	c #442B20",
"C@	c #4B3426",
"D@	c #36221D",
"E@	c #291815",
"F@	c #2A1814",
"G@	c #211010",
"H@	c #21110F",
"I@	c #251412",
"J@	c #35231B",
"K@	c #35241B",
"L@	c #2C1916",
"M@	c #3B271E",
"N@	c #2C1A15",
"O@	c #221312",
"P@	c #342119",
"Q@	c #32231B",
"R@	c #2C1C19",
"S@	c #3B2921",
"T@	c #392820",
"U@	c #443127",
"V@	c #7F736C",
"W@	c #FBFCFC",
"X@	c #F0ECEB",
"Y@	c #533F38",
"Z@	c #5E452E",
"`@	c #553E2F",
" #	c #5F4330",
".#	c #543A2A",
"+#	c #513729",
"@#	c #472E22",
"##	c #3F2A20",
"$#	c #33201A",
"%#	c #2C1A16",
"&#	c #2C1915",
"*#	c #2A1713",
"=#	c #2F1B15",
"-#	c #221110",
";#	c #22120F",
">#	c #231311",
",#	c #301D18",
"'#	c #39261E",
")#	c #2C1B15",
"!#	c #372821",
"~#	c #3A261D",
"{#	c #2E1B17",
"]#	c #311E17",
"^#	c #271915",
"/#	c #36231A",
"(#	c #312019",
"_#	c #33221A",
":#	c #33221C",
"<#	c #3B2B23",
"[#	c #4C362A",
"}#	c #AAA4A3",
"|#	c #A2948D",
"1#	c #553C2C",
"2#	c #4C372A",
"3#	c #5A422F",
"4#	c #5C4230",
"5#	c #503A2B",
"6#	c #5C402C",
"7#	c #442E23",
"8#	c #321D18",
"9#	c #2E1915",
"0#	c #301C15",
"a#	c #2E1914",
"b#	c #2C1914",
"c#	c #311C16",
"d#	c #261311",
"e#	c #23110F",
"f#	c #241210",
"g#	c #251311",
"h#	c #241211",
"i#	c #321E18",
"j#	c #2F1F1B",
"k#	c #3C2A21",
"l#	c #251614",
"m#	c #2E1E19",
"n#	c #39251C",
"o#	c #3A251D",
"p#	c #36241C",
"q#	c #3F2F26",
"r#	c #5A483D",
"s#	c #EDEAED",
"t#	c #F3EDEA",
"u#	c #654E3C",
"v#	c #463025",
"w#	c #442E24",
"x#	c #5B4330",
"y#	c #4A362B",
"z#	c #59402F",
"A#	c #4D3528",
"B#	c #402820",
"C#	c #3A241C",
"D#	c #2D1914",
"E#	c #39231A",
"F#	c #2E1A14",
"G#	c #362018",
"H#	c #372018",
"I#	c #281512",
"J#	c #251211",
"K#	c #291512",
"L#	c #271511",
"M#	c #2B1713",
"N#	c #281613",
"O#	c #321C17",
"P#	c #301D17",
"Q#	c #362119",
"R#	c #321F1A",
"S#	c #2E1B16",
"T#	c #2B1D19",
"U#	c #3A271F",
"V#	c #2C1D19",
"W#	c #32221D",
"X#	c #423227",
"Y#	c #928B8A",
"Z#	c #FFFAFF",
"`#	c #C0B1A6",
" $	c #463127",
".$	c #37251E",
"+$	c #523A2B",
"@$	c #412D24",
"#$	c #4E3628",
"$$	c #583D2B",
"%$	c #4E3326",
"&$	c #3E271F",
"*$	c #331E18",
"=$	c #2F1A15",
"-$	c #40271C",
";$	c #442A1E",
">$	c #43281D",
",$	c #472B1F",
"'$	c #3C231A",
")$	c #2A1512",
"!$	c #2F1914",
"~$	c #2B1512",
"{$	c #311B16",
"]$	c #2C1613",
"^$	c #342019",
"/$	c #331F19",
"($	c #362019",
"_$	c #351F18",
":$	c #321D17",
"<$	c #352018",
"[$	c #38231B",
"}$	c #341F18",
"|$	c #352119",
"1$	c #311D18",
"2$	c #241615",
"3$	c #34211B",
"4$	c #39261D",
"5$	c #321F1B",
"6$	c #3B2821",
"7$	c #31201B",
"8$	c #362721",
"9$	c #483A31",
"0$	c #D7D0D2",
"a$	c #FEFDFD",
"b$	c #766254",
"c$	c #36241E",
"d$	c #422C21",
"e$	c #3E2C23",
"f$	c #3D271F",
"g$	c #65432E",
"h$	c #422921",
"i$	c #38201A",
"j$	c #482D21",
"k$	c #543626",
"l$	c #513224",
"m$	c #573424",
"n$	c #62402C",
"o$	c #573727",
"p$	c #40271D",
"q$	c #321A14",
"r$	c #341D16",
"s$	c #331C16",
"t$	c #381F17",
"u$	c #361C16",
"v$	c #3C2219",
"w$	c #361E17",
"x$	c #37211B",
"y$	c #3C271E",
"z$	c #36211A",
"A$	c #361F18",
"B$	c #3A2219",
"C$	c #372119",
"D$	c #3D261D",
"E$	c #352019",
"F$	c #38231C",
"G$	c #32211B",
"H$	c #3C2921",
"I$	c #3C2820",
"J$	c #3C281F",
"K$	c #2E1D19",
"L$	c #3B2820",
"M$	c #3A2922",
"N$	c #3A2A22",
"O$	c #3C2C24",
"P$	c #786B65",
"Q$	c #FEFDFE",
"R$	c #D8D0CA",
"S$	c #402D24",
"T$	c #36221C",
"U$	c #462F23",
"V$	c #39241D",
"W$	c #422B20",
"X$	c #674A35",
"Y$	c #4F3426",
"Z$	c #3B221B",
"`$	c #533628",
" %	c #654531",
".%	c #614331",
"+%	c #5C3929",
"@%	c #754B34",
"#%	c #82553B",
"$%	c #6D4833",
"%%	c #4B2E21",
"&%	c #382018",
"*%	c #3D241A",
"=%	c #42271D",
"-%	c #3F2219",
";%	c #46281D",
">%	c #40251B",
",%	c #381F18",
"'%	c #412A21",
")%	c #3A231B",
"!%	c #371F18",
"~%	c #41261D",
"{%	c #3E241A",
"]%	c #3D241B",
"^%	c #39221B",
"/%	c #39251D",
"(%	c #351F19",
"_%	c #3D281F",
":%	c #40291F",
"<%	c #38241C",
"[%	c #3C2720",
"}%	c #3A2720",
"|%	c #402B22",
"1%	c #38241D",
"2%	c #38251E",
"3%	c #3C2A22",
"4%	c #372620",
"5%	c #3E2D24",
"6%	c #433127",
"7%	c #503D30",
"8%	c #D1CBCC",
"9%	c #84736A",
"0%	c #412C22",
"a%	c #3F2A21",
"b%	c #37231C",
"c%	c #5D422F",
"d%	c #58402F",
"e%	c #40251E",
"f%	c #533426",
"g%	c #6E4834",
"h%	c #78543C",
"i%	c #5F3D2C",
"j%	c #714A34",
"k%	c #84563B",
"l%	c #9A6647",
"m%	c #8C5C40",
"n%	c #492D22",
"o%	c #40261D",
"p%	c #452A1F",
"q%	c #4D2D20",
"r%	c #44291F",
"s%	c #49291D",
"t%	c #4B2C20",
"u%	c #482C20",
"v%	c #40241A",
"w%	c #42281E",
"x%	c #3B231A",
"y%	c #392119",
"z%	c #42261C",
"A%	c #482A1F",
"B%	c #3A2119",
"C%	c #3B251C",
"D%	c #3A251E",
"E%	c #301C18",
"F%	c #3F2920",
"G%	c #37221B",
"H%	c #281A17",
"I%	c #3D2921",
"J%	c #422E24",
"K%	c #3E2B22",
"L%	c #33231D",
"M%	c #3D2A22",
"N%	c #36251F",
"O%	c #34251F",
"P%	c #3D2C24",
"Q%	c #3F2F28",
"R%	c #4C392C",
"S%	c #9C8A81",
"T%	c #E7E2E2",
"U%	c #403028",
"V%	c #412C23",
"W%	c #38241E",
"X%	c #4B3326",
"Y%	c #584030",
"Z%	c #432A21",
"`%	c #482D22",
" &	c #674230",
".&	c #80553D",
"+&	c #75523B",
"@&	c #67422F",
"#&	c #7D5238",
"$&	c #965F43",
"%&	c #C78D62",
"&&	c #A6704F",
"*&	c #533326",
"=&	c #492C21",
"-&	c #543323",
";&	c #4D2F21",
">&	c #553222",
",&	c #492B20",
"'&	c #47281E",
")&	c #44271C",
"!&	c #42251B",
"~&	c #482B20",
"{&	c #4F2E22",
"]&	c #4E2E22",
"^&	c #36201A",
"/&	c #3A261F",
"(&	c #341F1A",
"_&	c #35211B",
":&	c #39231D",
"<&	c #392620",
"[&	c #3B261E",
"}&	c #37241E",
"|&	c #412B23",
"1&	c #3F2D26",
"2&	c #442F26",
"3&	c #33211C",
"4&	c #3C2821",
"5&	c #3A2821",
"6&	c #3E2D26",
"7&	c #3C2B24",
"8&	c #453429",
"9&	c #7C6A5D",
"0&	c #FFFEFD",
"a&	c #BDB3AA",
"b&	c #382620",
"c&	c #3D2920",
"d&	c #533A2B",
"e&	c #44281E",
"f&	c #593528",
"g&	c #744834",
"h&	c #8B5C42",
"i&	c #6A4230",
"j&	c #7E543A",
"k&	c #8C5B3E",
"l&	c #B37A55",
"m&	c #E09D70",
"n&	c #C58A60",
"o&	c #613B2A",
"p&	c #543324",
"q&	c #68422C",
"r&	c #4E3024",
"s&	c #5F3A29",
"t&	c #5C3728",
"u&	c #533122",
"v&	c #4F2E21",
"w&	c #4E2C20",
"x&	c #4D291D",
"y&	c #4A2A1F",
"z&	c #45281D",
"A&	c #46291F",
"B&	c #5A3627",
"C&	c #5D3627",
"D&	c #4A2B20",
"E&	c #3C231B",
"F&	c #38221B",
"G&	c #3B271F",
"H&	c #34201A",
"I&	c #34201B",
"J&	c #32201C",
"K&	c #443026",
"L&	c #412E25",
"M&	c #403027",
"N&	c #372720",
"O&	c #3D2A23",
"P&	c #3C2A23",
"Q&	c #3B2C25",
"R&	c #413128",
"S&	c #423027",
"T&	c #6F6356",
"U&	c #A19389",
"V&	c #3E2921",
"W&	c #473125",
"X&	c #442C22",
"Y&	c #3D251C",
"Z&	c #4B2D23",
"`&	c #673F2D",
" *	c #86583D",
".*	c #89593E",
"+*	c #7F4E36",
"@*	c #946144",
"#*	c #9D6446",
"$*	c #D49269",
"%*	c #E59E71",
"&*	c #DA9A6B",
"**	c #724531",
"=*	c #5B3B2B",
"-*	c #7E5236",
";*	c #4F2F25",
">*	c #744833",
",*	c #693F2D",
"'*	c #5C3726",
")*	c #512F21",
"!*	c #5F3625",
"~*	c #512E20",
"{*	c #522F21",
"]*	c #4C2E23",
"^*	c #593628",
"/*	c #683E2C",
"(*	c #583224",
"_*	c #43261D",
":*	c #39211A",
"<*	c #311B17",
"[*	c #37261F",
"}*	c #34201C",
"|*	c #311D19",
"1*	c #3F2A22",
"2*	c #413027",
"3*	c #49342A",
"4*	c #3B2923",
"5*	c #3F2E25",
"6*	c #3C2923",
"7*	c #3A2A23",
"8*	c #45342B",
"9*	c #574338",
"0*	c #F4F3F5",
"a*	c #847268",
"b*	c #452D23",
"c*	c #3D251D",
"d*	c #41251D",
"e*	c #593527",
"f*	c #764C35",
"g*	c #8E5D40",
"h*	c #8C5A3E",
"i*	c #956143",
"j*	c #9B6747",
"k*	c #BC7E57",
"l*	c #E69F70",
"m*	c #F2A977",
"n*	c #E39E6E",
"o*	c #915C3F",
"p*	c #604030",
"q*	c #9D6B48",
"r*	c #563324",
"s*	c #754C36",
"t*	c #704532",
"u*	c #73442F",
"v*	c #573121",
"w*	c #512D21",
"x*	c #6A402E",
"y*	c #663827",
"z*	c #533022",
"A*	c #4C2D22",
"B*	c #4F3126",
"C*	c #734731",
"D*	c #6C402C",
"E*	c #522D20",
"F*	c #3D221A",
"G*	c #351E18",
"H*	c #321B17",
"I*	c #35211C",
"J*	c #2E1C18",
"K*	c #3E2A22",
"L*	c #422F26",
"M*	c #35221C",
"N*	c #372722",
"O*	c #433129",
"P*	c #402D25",
"Q*	c #362621",
"R*	c #382A25",
"S*	c #3E2F28",
"T*	c #3E2D27",
"U*	c #402F27",
"V*	c #3E2E27",
"W*	c #42332B",
"X*	c #4D3B2E",
"Y*	c #D5D3D4",
"Z*	c #FEFCFC",
"`*	c #5F493A",
" =	c #3F2B22",
".=	c #422C23",
"+=	c #462E23",
"@=	c #3D241D",
"#=	c #68402E",
"$=	c #815139",
"%=	c #925E41",
"&=	c #966144",
"*=	c #9E6949",
"==	c #B37C57",
"-=	c #DC986C",
";=	c #F2A775",
">=	c #FCB481",
",=	c #FAB581",
"'=	c #AD724E",
")=	c #6B4430",
"!=	c #A8734E",
"~=	c #69402C",
"{=	c #6F4934",
"]=	c #784A34",
"^=	c #805036",
"/=	c #633A28",
"(=	c #5D3526",
"_=	c #603829",
":=	c #693C29",
"<=	c #583122",
"[=	c #532F23",
"}=	c #482920",
"|=	c #563729",
"1=	c #764A35",
"2=	c #70402C",
"3=	c #4C281E",
"4=	c #391F19",
"5=	c #341C17",
"6=	c #47352B",
"7=	c #413029",
"8=	c #33221E",
"9=	c #372924",
"0=	c #3B2B25",
"a=	c #352622",
"b=	c #392C27",
"c=	c #392D28",
"d=	c #3A2E27",
"e=	c #513D30",
"f=	c #BFB6B2",
"g=	c #FFF9FF",
"h=	c #FFFAF3",
"i=	c #594131",
"j=	c #402B23",
"k=	c #4C3326",
"l=	c #3C241D",
"m=	c #3F251C",
"n=	c #5C3627",
"o=	c #764833",
"p=	c #8C593E",
"q=	c #945F42",
"r=	c #9E6547",
"s=	c #D29568",
"t=	c #F4AC7A",
"u=	c #FEB682",
"v=	c #FFBF89",
"w=	c #FEBE8A",
"x=	c #B37650",
"y=	c #7B5037",
"z=	c #9F6E4C",
"A=	c #774B34",
"B=	c #644232",
"C=	c #885338",
"D=	c #834F37",
"E=	c #72432D",
"F=	c #633A29",
"G=	c #754430",
"H=	c #844C33",
"I=	c #6F3D29",
"J=	c #633725",
"K=	c #562F21",
"L=	c #4F2A1F",
"M=	c #512F23",
"N=	c #6B412F",
"O=	c #643827",
"P=	c #43241B",
"Q=	c #331C17",
"R=	c #2F1B17",
"S=	c #311E1A",
"T=	c #372520",
"U=	c #382823",
"V=	c #3B2B24",
"W=	c #413129",
"X=	c #33231F",
"Y=	c #32221E",
"Z=	c #36241F",
"`=	c #2E1F1D",
" -	c #302421",
".-	c #3B2D27",
"+-	c #342723",
"@-	c #3F302A",
"#-	c #372824",
"$-	c #503F32",
"%-	c #AB9FA0",
"&-	c #FEFBF9",
"*-	c #4F3629",
"=-	c #462F24",
"--	c #503728",
";-	c #432820",
">-	c #492A20",
",-	c #6A3F2C",
"'-	c #825138",
")-	c #8E583C",
"!-	c #9C6244",
"~-	c #A86E4B",
"{-	c #CC8C5F",
"]-	c #F5B380",
"^-	c #FFBB84",
"/-	c #FFC08A",
"(-	c #FFC38D",
"_-	c #FFBF88",
":-	c #C08057",
"<-	c #845339",
"[-	c #81563E",
"}-	c #865238",
"|-	c #663E2B",
"1-	c #935A3C",
"2-	c #8D593C",
"3-	c #844D34",
"4-	c #6D3F2C",
"5-	c #83543A",
"6-	c #A96B4B",
"7-	c #A06345",
"8-	c #8B5237",
"9-	c #885034",
"0-	c #703E29",
"a-	c #78422A",
"b-	c #633524",
"c-	c #3C211A",
"d-	c #39201A",
"e-	c #331D18",
"f-	c #2F1B18",
"g-	c #301D1A",
"h-	c #2F1D1A",
"i-	c #32211D",
"j-	c #2E1D1A",
"k-	c #322421",
"l-	c #312320",
"m-	c #2B1C1A",
"n-	c #2D1E1B",
"o-	c #2A1C1B",
"p-	c #392B26",
"q-	c #372823",
"r-	c #473A30",
"s-	c #9D8F8C",
"t-	c #53382A",
"u-	c #493125",
"v-	c #533829",
"w-	c #4C3024",
"x-	c #513123",
"y-	c #794932",
"z-	c #925C3F",
"A-	c #955D40",
"B-	c #A26747",
"C-	c #BF7E56",
"D-	c #EEA877",
"E-	c #FFC794",
"F-	c #FFC28D",
"G-	c #FFC48F",
"H-	c #FFCA95",
"I-	c #D39365",
"J-	c #8E593C",
"K-	c #835639",
"L-	c #915B3F",
"M-	c #7A452E",
"N-	c #9B6041",
"O-	c #95593D",
"P-	c #9B5D40",
"Q-	c #7D4B33",
"R-	c #794731",
"S-	c #BB7A57",
"T-	c #B67250",
"U-	c #AA6B4A",
"V-	c #B37350",
"W-	c #A36344",
"X-	c #A36545",
"Y-	c #9B5C3C",
"Z-	c #834C33",
"`-	c #6A3F2B",
" ;	c #502B1E",
".;	c #3B2019",
"+;	c #331C18",
"@;	c #311C19",
"#;	c #2D1917",
"$;	c #2E1B18",
"%;	c #2D1B19",
"&;	c #2B1A19",
"*;	c #2C1B19",
"=;	c #2C1C1A",
"-;	c #2A1918",
";;	c #2C1B1A",
">;	c #2D1F1C",
",;	c #2D201E",
"';	c #2F221F",
");	c #322622",
"!;	c #382924",
"~;	c #43362D",
"{;	c #998680",
"];	c #877162",
"^;	c #35241E",
"/;	c #442D24",
"(;	c #4F3427",
"_;	c #4E3126",
":;	c #563425",
"<;	c #8B583D",
"[;	c #9B6245",
"};	c #A36748",
"|;	c #B4734F",
"1;	c #EA9F6E",
"2;	c #FFC18C",
"3;	c #FFC793",
"4;	c #FFC491",
"5;	c #FFC490",
"6;	c #FFC592",
"7;	c #E5A172",
"8;	c #996141",
"9;	c #955E41",
"0;	c #A06446",
"a;	c #9C5B3E",
"b;	c #AD6B49",
"c;	c #AE6B4A",
"d;	c #874E37",
"e;	c #885237",
"f;	c #A96E50",
"g;	c #C47F5B",
"h;	c #BC7B58",
"i;	c #BC7C57",
"j;	c #C27E5A",
"k;	c #BB7956",
"l;	c #B67552",
"m;	c #A16244",
"n;	c #925C40",
"o;	c #77442E",
"p;	c #4C291E",
"q;	c #2E1A18",
"r;	c #2D1B18",
"s;	c #2B1817",
"t;	c #2B1918",
"u;	c #291818",
"v;	c #2A1A19",
"w;	c #291918",
"x;	c #2B1B1A",
"y;	c #2A1B1B",
"z;	c #2C1E1D",
"A;	c #2F2320",
"B;	c #372923",
"C;	c #41322A",
"D;	c #847372",
"E;	c #B4A498",
"F;	c #3E2B23",
"G;	c #503527",
"H;	c #543527",
"I;	c #623B2A",
"J;	c #AB714D",
"K;	c #A46A4A",
"L;	c #B87650",
"M;	c #E49968",
"N;	c #FFBA83",
"O;	c #FFC590",
"P;	c #FFC996",
"Q;	c #FFC48E",
"R;	c #FFC791",
"S;	c #FFC993",
"T;	c #F9B682",
"U;	c #A66646",
"V;	c #B36F49",
"W;	c #B97850",
"X;	c #B5704C",
"Y;	c #BC7650",
"Z;	c #C17B54",
"`;	c #BC7550",
" >	c #8B5137",
".>	c #8D553D",
"+>	c #9D6245",
"@>	c #C27F5B",
"#>	c #C5825C",
"$>	c #C7875F",
"%>	c #C9855E",
"&>	c #C9865F",
"*>	c #C17E59",
"=>	c #B06E4D",
"->	c #A16849",
";>	c #9A6144",
">>	c #71402C",
",>	c #48261D",
"'>	c #361E19",
")>	c #291817",
"!>	c #2A1817",
"~>	c #271717",
"{>	c #281818",
"]>	c #2B1C1B",
"^>	c #2A1C1C",
"/>	c #291B1B",
"(>	c #2B1F1E",
"_>	c #362823",
":>	c #3E3028",
"<>	c #7F6E6F",
"[>	c #E4DBD3",
"}>	c #453026",
"|>	c #69432F",
"1>	c #7B4D36",
"2>	c #C18159",
"3>	c #BB7C56",
"4>	c #E89B6C",
"5>	c #FEB883",
"6>	c #FFC591",
"7>	c #FFCC9C",
"8>	c #FFCD9B",
"9>	c #FFC391",
"0>	c #FFCB98",
"a>	c #FFC795",
"b>	c #AD6D49",
"c>	c #D08C61",
"d>	c #CD8459",
"e>	c #D5895F",
"f>	c #CF885F",
"g>	c #C57F58",
"h>	c #A16243",
"i>	c #895139",
"j>	c #B87754",
"k>	c #C17E5A",
"l>	c #CD8863",
"m>	c #CB8963",
"n>	c #CE8B63",
"o>	c #CD8860",
"p>	c #C8835C",
"q>	c #B77654",
"r>	c #A96F4F",
"s>	c #AA6D4D",
"t>	c #9C6245",
"u>	c #6E402C",
"v>	c #44221A",
"w>	c #351D18",
"x>	c #301A18",
"y>	c #2A1716",
"z>	c #251616",
"A>	c #271818",
"B>	c #2A1B1A",
"C>	c #2A1D1C",
"D>	c #342622",
"E>	c #867771",
"F>	c #5C483F",
"G>	c #4D372B",
"H>	c #553B2D",
"I>	c #885A3E",
"J>	c #A46C49",
"K>	c #CD8B62",
"L>	c #E9A574",
"M>	c #FEB884",
"N>	c #FFBE8A",
"O>	c #FFC18F",
"P>	c #FFCA97",
"Q>	c #FFCC98",
"R>	c #FFC08D",
"S>	c #FFC290",
"T>	c #FFC28F",
"U>	c #FFC792",
"V>	c #FFC390",
"W>	c #D79060",
"X>	c #D28B63",
"Y>	c #F2A473",
"Z>	c #E6956A",
"`>	c #E1936A",
" ,	c #D99168",
".,	c #CF8A63",
"+,	c #B97754",
"@,	c #91553D",
"#,	c #B17656",
"$,	c #CC8965",
"%,	c #CC8B66",
"&,	c #D08D67",
"*,	c #D4916A",
"=,	c #D28C65",
"-,	c #CF8963",
";,	c #BC7D59",
">,	c #B07352",
",,	c #AF7250",
"',	c #AC7250",
"),	c #9A5E42",
"!,	c #673828",
"~,	c #40211A",
"{,	c #331B18",
"],	c #2D1817",
"^,	c #251617",
"/,	c #241617",
"(,	c #281919",
"_,	c #291A1A",
":,	c #281B1A",
"<,	c #291C1C",
"[,	c #2D1F1E",
"},	c #342722",
"|,	c #827470",
"1,	c #8C7060",
"2,	c #483228",
"3,	c #593F30",
"4,	c #AE7954",
"5,	c #DD966B",
"6,	c #EAA071",
"7,	c #FEB684",
"8,	c #FFBB89",
"9,	c #FFBC8A",
"0,	c #FFCC9A",
"a,	c #FFBB8A",
"b,	c #FFC693",
"c,	c #F5B17F",
"d,	c #D98A5F",
"e,	c #D78D64",
"f,	c #E3966F",
"g,	c #E69A71",
"h,	c #DE9870",
"i,	c #D8926B",
"j,	c #D08964",
"k,	c #995D41",
"l,	c #A97154",
"m,	c #C28263",
"n,	c #C48465",
"o,	c #D08F6B",
"p,	c #D0906C",
"q,	c #CC8C67",
"r,	c #C68663",
"s,	c #BE805C",
"t,	c #B37654",
"u,	c #B47451",
"v,	c #B07252",
"w,	c #9C6043",
"x,	c #6A3D2A",
"y,	c #45261D",
"z,	c #38201B",
"A,	c #321D1A",
"B,	c #2D1A19",
"C,	c #271718",
"D,	c #261818",
"E,	c #261819",
"F,	c #2B1C1C",
"G,	c #2A1D1D",
"H,	c #2C1F1E",
"I,	c #3C2D28",
"J,	c #817172",
"K,	c #B1998C",
"L,	c #513B30",
"M,	c #5C4031",
"N,	c #D59A6E",
"O,	c #F1A87B",
"P,	c #FEB285",
"Q,	c #FFB487",
"R,	c #FFB687",
"S,	c #FFB585",
"T,	c #FFB888",
"U,	c #FFBE8C",
"V,	c #FFC08F",
"W,	c #FFC393",
"X,	c #FFC191",
"Y,	c #FFC291",
"Z,	c #FFC593",
"`,	c #FFC192",
" '	c #FFBC8C",
".'	c #EF9E71",
"+'	c #DE9067",
"@'	c #E99D72",
"#'	c #E49D76",
"$'	c #D89873",
"%'	c #D29472",
"&'	c #BD8363",
"*'	c #A16B4F",
"='	c #895945",
"-'	c #9C6951",
";'	c #9B664F",
">'	c #A9765B",
",'	c #A36C53",
"''	c #A66F55",
")'	c #AE7558",
"!'	c #B97C5B",
"~'	c #AF7555",
"{'	c #AF7453",
"]'	c #B17553",
"^'	c #B67B56",
"/'	c #B67957",
"('	c #A46B4A",
"_'	c #7F4C34",
":'	c #583427",
"<'	c #3F261F",
"['	c #35201D",
"}'	c #301D1B",
"|'	c #2B1A1A",
"1'	c #2A1A1B",
"2'	c #2B1D1D",
"3'	c #2B1E1D",
"4'	c #3D2C26",
"5'	c #3E302A",
"6'	c #8A7B78",
"7'	c #DAC8BB",
"8'	c #573F31",
"9'	c #6A4C39",
"0'	c #D7A27A",
"a'	c #D69871",
"b'	c #E6A079",
"c'	c #EFA97E",
"d'	c #F3AB81",
"e'	c #F4AC82",
"f'	c #F8AE80",
"g'	c #FDB484",
"h'	c #FFB385",
"i'	c #FFBA8A",
"j'	c #FFBE8E",
"k'	c #FFBD8B",
"l'	c #FFBA8B",
"m'	c #FFB484",
"n'	c #FAA97E",
"o'	c #E49971",
"p'	c #CE8A68",
"q'	c #AD775D",
"r'	c #855B47",
"s'	c #654033",
"t'	c #5C3C31",
"u'	c #5B3A2E",
"v'	c #5A382B",
"w'	c #603C2F",
"x'	c #734C3C",
"y'	c #805643",
"z'	c #7D543F",
"A'	c #8B5F49",
"B'	c #9F6B53",
"C'	c #A97257",
"D'	c #A97256",
"E'	c #A57051",
"F'	c #B77A56",
"G'	c #BE7F5A",
"H'	c #C2805D",
"I'	c #C07F5D",
"J'	c #B57754",
"K'	c #905F44",
"L'	c #5A392B",
"M'	c #3D2620",
"N'	c #37231F",
"O'	c #3C2924",
"P'	c #33211E",
"Q'	c #2E1E1C",
"R'	c #2C1E1E",
"S'	c #312321",
"T'	c #30221F",
"U'	c #3B2825",
"V'	c #6B4437",
"W'	c #6D4B3B",
"X'	c #B1A5A2",
"Y'	c #F8F3EF",
"Z'	c #614738",
"`'	c #745A46",
" )	c #9F775C",
".)	c #8D654C",
"+)	c #86614B",
"@)	c #7F5A46",
"#)	c #7C5643",
"$)	c #90654D",
"%)	c #BC8462",
"&)	c #D69870",
"*)	c #EFA77C",
"=)	c #FBAD80",
"-)	c #FEB484",
";)	c #FFB988",
">)	c #FFB486",
",)	c #FFB887",
"')	c #F8AA7D",
"))	c #DD9670",
"!)	c #BC805E",
"~)	c #96644B",
"{)	c #744B3A",
"])	c #57352C",
"^)	c #4D2E26",
"/)	c #472821",
"()	c #462720",
"_)	c #533227",
":)	c #613B2E",
"<)	c #654032",
"[)	c #6F4636",
"})	c #7E5240",
"|)	c #92614A",
"1)	c #9D6950",
"2)	c #9C6750",
"3)	c #9E6C53",
"4)	c #9E6E52",
"5)	c #B17958",
"6)	c #C1835E",
"7)	c #C58360",
"8)	c #C58260",
"9)	c #BF7E5C",
"0)	c #A97352",
"a)	c #714C39",
"b)	c #4A3027",
"c)	c #3B2621",
"d)	c #3A2824",
"e)	c #3B2823",
"f)	c #31211E",
"g)	c #2C1D1D",
"h)	c #30201F",
"i)	c #382623",
"j)	c #735042",
"k)	c #9F644C",
"l)	c #9D6650",
"m)	c #F6EEEE",
"n)	c #AA8C72",
"o)	c #745B46",
"p)	c #835F48",
"q)	c #704E3C",
"r)	c #5A3F32",
"s)	c #53382D",
"t)	c #503329",
"u)	c #54352A",
"v)	c #664233",
"w)	c #8C6049",
"x)	c #B87F5D",
"y)	c #DE996F",
"z)	c #F4A97B",
"A)	c #FFB384",
"B)	c #FDAA7C",
"C)	c #F3A577",
"D)	c #D08B65",
"E)	c #AA7253",
"F)	c #946348",
"G)	c #82523D",
"H)	c #754735",
"I)	c #6F4130",
"J)	c #603729",
"K)	c #542A22",
"L)	c #5A3027",
"M)	c #60392D",
"N)	c #643C2F",
"O)	c #6B4233",
"P)	c #794E3B",
"Q)	c #895944",
"R)	c #A46C54",
"S)	c #A76F56",
"T)	c #AB7459",
"U)	c #AD7459",
"V)	c #A87659",
"W)	c #AD7A5A",
"X)	c #BD825E",
"Y)	c #C68562",
"Z)	c #C98362",
"`)	c #C3815E",
" !	c #B57758",
".!	c #855841",
"+!	c #52372C",
"@!	c #3E2923",
"#!	c #372421",
"$!	c #3A2723",
"%!	c #32201E",
"&!	c #432C26",
"*!	c #664235",
"=!	c #815343",
"-!	c #9C5C4B",
";!	c #A25947",
">!	c #F7EEF5",
",!	c #F1E4D4",
"'!	c #84684E",
")!	c #7B5742",
"!!	c #704C39",
"~!	c #734C39",
"{!	c #6E4836",
"]!	c #65402E",
"^!	c #5D362C",
"/!	c #5C342B",
"(!	c #664332",
"_!	c #7E543E",
":!	c #AA7454",
"<!	c #DC976D",
"[!	c #F1A375",
"}!	c #EFA074",
"|!	c #DD9169",
"1!	c #C4805C",
"2!	c #A0684A",
"3!	c #905C43",
"4!	c #8A553E",
"5!	c #7E4A36",
"6!	c #6E3C2C",
"7!	c #613327",
"8!	c #613328",
"9!	c #62382D",
"0!	c #603A2F",
"a!	c #6B4637",
"b!	c #7B4939",
"c!	c #784638",
"d!	c #774636",
"e!	c #8D5D48",
"f!	c #A87055",
"g!	c #B1785B",
"h!	c #B1775B",
"i!	c #B07B5C",
"j!	c #B37D5C",
"k!	c #B77F5C",
"l!	c #C28260",
"m!	c #C88460",
"n!	c #C68461",
"o!	c #BD7D5B",
"p!	c #956449",
"q!	c #57392D",
"r!	c #422C26",
"s!	c #362420",
"t!	c #392723",
"u!	c #3B2723",
"v!	c #4F342C",
"w!	c #73493B",
"x!	c #98654F",
"y!	c #B06751",
"z!	c #B5604A",
"A!	c #F3DEDC",
"B!	c #FFF8EF",
"C!	c #8E7257",
"D!	c #A47A5D",
"E!	c #906149",
"F!	c #7D4F3C",
"G!	c #6A3C31",
"H!	c #65392F",
"I!	c #6A4032",
"J!	c #693F31",
"K!	c #64362C",
"L!	c #5B3026",
"M!	c #7A4E39",
"N!	c #C78A62",
"O!	c #EFA373",
"P!	c #EC9C70",
"Q!	c #DF996D",
"R!	c #CB8962",
"S!	c #AD6E4E",
"T!	c #9C6146",
"U!	c #87513B",
"V!	c #774533",
"W!	c #704031",
"X!	c #6D3A2C",
"Y!	c #63372B",
"Z!	c #5A3E32",
"`!	c #3D2A27",
" ~	c #462827",
".~	c #402925",
"+~	c #603D34",
"@~	c #7D5040",
"#~	c #7B4836",
"$~	c #80503C",
"%~	c #9E684D",
"&~	c #A97456",
"*~	c #AE7D5E",
"=~	c #B8815F",
"-~	c #BB805E",
";~	c #C0815F",
">~	c #C78562",
",~	c #C78460",
"'~	c #C1805F",
")~	c #A36E50",
"!~	c #5E3D30",
"~~	c #473029",
"{~	c #3D2924",
"]~	c #3A2823",
"^~	c #3F2A26",
"/~	c #462D28",
"(~	c #593D31",
"_~	c #8B5544",
":~	c #C68263",
"<~	c #B86C53",
"[~	c #C5654E",
"}~	c #EECCCF",
"|~	c #9D795A",
"1~	c #C99C77",
"2~	c #97684D",
"3~	c #794B3B",
"4~	c #6E4839",
"5~	c #533930",
"6~	c #3B2927",
"7~	c #3A2623",
"8~	c #563D33",
"9~	c #7D4B38",
"0~	c #754433",
"a~	c #8E5E45",
"b~	c #F0A675",
"c~	c #FBA879",
"d~	c #EEA073",
"e~	c #D29068",
"f~	c #B87856",
"g~	c #9D654A",
"h~	c #814E3B",
"i~	c #764738",
"j~	c #734232",
"k~	c #6F392C",
"l~	c #815C47",
"m~	c #9C8366",
"n~	c #4A3E35",
"o~	c #2A1A1F",
"p~	c #3B2D28",
"q~	c #665546",
"r~	c #5F4237",
"s~	c #6C4033",
"t~	c #7C4834",
"u~	c #8F5940",
"v~	c #A36D4E",
"w~	c #B17C59",
"x~	c #BD825F",
"y~	c #C08462",
"z~	c #BF8160",
"A~	c #C68563",
"B~	c #CA8663",
"C~	c #C27F5F",
"D~	c #A86E51",
"E~	c #6D4837",
"F~	c #49322A",
"G~	c #3C2B26",
"H~	c #463029",
"I~	c #55352C",
"J~	c #6C483C",
"K~	c #C78569",
"L~	c #D98E6D",
"M~	c #C17459",
"N~	c #CF6B51",
"O~	c #F4CFCD",
"P~	c #B79678",
"Q~	c #DAAC84",
"R~	c #98694E",
"S~	c #6C4C3C",
"T~	c #785D4A",
"U~	c #736757",
"V~	c #3C3330",
"W~	c #372832",
"X~	c #5B4D3C",
"Y~	c #A68A6A",
"Z~	c #8E5B48",
"`~	c #824E37",
" {	c #E4A779",
".{	c #FFC595",
"+{	c #FDB583",
"@{	c #DE976F",
"#{	c #B77A58",
"${	c #9C654C",
"%{	c #8F5845",
"&{	c #A36C4F",
"*{	c #91563E",
"={	c #804233",
"-{	c #875441",
";{	c #AA886B",
">{	c #92785F",
",{	c #665543",
"'{	c #766252",
"){	c #A38771",
"!{	c #9A6A53",
"~{	c #804E3D",
"{{	c #92573F",
"]{	c #9D5F45",
"^{	c #C0835F",
"/{	c #C98C65",
"({	c #C58663",
"_{	c #C38361",
":{	c #C78663",
"<{	c #C98663",
"[{	c #C07D5C",
"}{	c #AC7052",
"|{	c #744D3A",
"1{	c #4B342C",
"2{	c #3E2C27",
"3{	c #49322C",
"4{	c #5D3C30",
"5{	c #643D30",
"6{	c #73473A",
"7{	c #AA6C55",
"8{	c #C47A60",
"9{	c #C7765D",
"0{	c #C86750",
"a{	c #FBE4E2",
"b{	c #D4BDA5",
"c{	c #E5B58B",
"d{	c #AB7858",
"e{	c #764A37",
"f{	c #A57D64",
"g{	c #A79678",
"h{	c #625644",
"i{	c #544536",
"j{	c #8B725B",
"k{	c #B48665",
"l{	c #9A5B49",
"m{	c #A5684A",
"n{	c #E39B71",
"o{	c #FCA77A",
"p{	c #DE8D68",
"q{	c #BA7656",
"r{	c #A46A51",
"s{	c #925C49",
"t{	c #95634F",
"u{	c #925C46",
"v{	c #874D3A",
"w{	c #8A4D3C",
"x{	c #A26350",
"y{	c #B47863",
"z{	c #AC735E",
"A{	c #AD725C",
"B{	c #A66350",
"C{	c #9E6049",
"D{	c #A4684D",
"E{	c #B57556",
"F{	c #C68662",
"G{	c #CC8A65",
"H{	c #D08C67",
"I{	c #CF8C67",
"J{	c #C98964",
"K{	c #C68561",
"L{	c #C58261",
"M{	c #B27657",
"N{	c #7E523E",
"O{	c #4F352D",
"P{	c #3A2724",
"Q{	c #432E29",
"R{	c #6E4636",
"S{	c #6E4435",
"T{	c #7C4738",
"U{	c #904E3D",
"V{	c #AB644E",
"W{	c #C87359",
"X{	c #CD745F",
"Y{	c #FFFBFC",
"Z{	c #EFDECD",
"`{	c #EFBA92",
" ]	c #CB8E66",
".]	c #B27957",
"+]	c #AD775F",
"@]	c #AF7960",
"#]	c #AB8069",
"$]	c #AE7860",
"%]	c #B5705A",
"&]	c #AD654F",
"*]	c #A8654D",
"=]	c #B07357",
"-]	c #ED9470",
";]	c #FFAA7E",
">]	c #F79871",
",]	c #D68363",
"']	c #BF7356",
")]	c #B77255",
"!]	c #A46750",
"~]	c #915C4B",
"{]	c #8A5645",
"]]	c #8F5644",
"^]	c #9F634A",
"/]	c #AE6D4F",
"(]	c #B47254",
"_]	c #B16D50",
":]	c #AC6B51",
"<]	c #AD6B51",
"[]	c #B37555",
"}]	c #C48460",
"|]	c #D38E68",
"1]	c #DD966C",
"2]	c #E09970",
"3]	c #D7956E",
"4]	c #CF8D67",
"5]	c #CA8964",
"6]	c #CA8965",
"7]	c #CA8966",
"8]	c #C3825F",
"9]	c #BF7D5D",
"0]	c #B27658",
"a]	c #825540",
"b]	c #50352C",
"c]	c #3A2522",
"d]	c #3F2B28",
"e]	c #6F4A3A",
"f]	c #845140",
"g]	c #AD6854",
"h]	c #AA5C46",
"i]	c #A05542",
"j]	c #C26F58",
"k]	c #D58F83",
"l]	c #FEF7F5",
"m]	c #F9BF93",
"n]	c #EBA677",
"o]	c #DC9B6E",
"p]	c #BA8563",
"q]	c #AF7356",
"r]	c #AD6E57",
"s]	c #AC674F",
"t]	c #A66149",
"u]	c #A56149",
"v]	c #B9785C",
"w]	c #CE8D6B",
"x]	c #F4926D",
"y]	c #FE9E74",
"z]	c #E48660",
"A]	c #CD7C5D",
"B]	c #C37358",
"C]	c #C37157",
"D]	c #BC6F52",
"E]	c #B67759",
"F]	c #AE735A",
"G]	c #C38768",
"H]	c #C78667",
"I]	c #C78264",
"J]	c #C98364",
"K]	c #CB8662",
"L]	c #D28D67",
"M]	c #E0996E",
"N]	c #EFA478",
"O]	c #F4A97E",
"P]	c #F4A77A",
"Q]	c #EC9E74",
"R]	c #DE936D",
"S]	c #D6906A",
"T]	c #CF8B66",
"U]	c #CB8A67",
"V]	c #C38562",
"W]	c #BB7C5C",
"X]	c #AB7154",
"Y]	c #805540",
"Z]	c #52372E",
"`]	c #432C27",
" ^	c #4A312A",
".^	c #614337",
"+^	c #A06850",
"@^	c #D2886F",
"#^	c #CA745B",
"$^	c #A75946",
"%^	c #C6745D",
"&^	c #E3AEA8",
"*^	c #FFFAF9",
"=^	c #FECCA4",
"-^	c #FBB280",
";^	c #F8AD7E",
">^	c #DF996E",
",^	c #BC7E5B",
"'^	c #B07356",
")^	c #B17053",
"!^	c #BA795C",
"~^	c #D4936F",
"{^	c #E19D74",
"]^	c #E1976F",
"^^	c #F69B72",
"/^	c #FA9E73",
"(^	c #DC8361",
"_^	c #C9795C",
":^	c #CC765B",
"<^	c #CB765C",
"[^	c #CF7B5E",
"}^	c #D28361",
"|^	c #DC9370",
"1^	c #E49F79",
"2^	c #EDA57A",
"3^	c #EAA479",
"4^	c #E99D74",
"5^	c #E99874",
"6^	c #F09F78",
"7^	c #F1A478",
"8^	c #F9AD81",
"9^	c #F5A67A",
"0^	c #FCAF83",
"a^	c #FAAA7F",
"b^	c #F0A177",
"c^	c #E6966E",
"d^	c #DA8C65",
"e^	c #D08A67",
"f^	c #C98965",
"g^	c #C28462",
"h^	c #BD805E",
"i^	c #B6795B",
"j^	c #A56C51",
"k^	c #764E3D",
"l^	c #55362D",
"m^	c #4F362E",
"n^	c #805945",
"o^	c #B67D5F",
"p^	c #C37D60",
"q^	c #E09278",
"r^	c #C36E57",
"s^	c #AA5A47",
"t^	c #C87C64",
"u^	c #F3D1CC",
"v^	c #FFFCFE",
"w^	c #FFD2AF",
"x^	c #FFB68A",
"y^	c #FFB684",
"z^	c #FAB080",
"A^	c #ECA376",
"B^	c #E39B72",
"C^	c #D9956F",
"D^	c #E19870",
"E^	c #F3A77A",
"F^	c #F6A47A",
"G^	c #E99B74",
"H^	c #FDA37A",
"I^	c #FB9D77",
"J^	c #DF8163",
"K^	c #C87459",
"L^	c #CB7A5E",
"M^	c #CD7C5E",
"N^	c #D07D60",
"O^	c #D98768",
"P^	c #EB9870",
"Q^	c #F9A67B",
"R^	c #FDA67A",
"S^	c #FEA475",
"T^	c #FEAA7D",
"U^	c #FEAB7B",
"V^	c #FBA378",
"W^	c #FEA679",
"X^	c #FFAF82",
"Y^	c #FFAC81",
"Z^	c #FEAA7F",
"`^	c #FAA47A",
" /	c #F49F74",
"./	c #EB9771",
"+/	c #E1926B",
"@/	c #D28764",
"#/	c #CC8764",
"$/	c #C48161",
"%/	c #B67B5C",
"&/	c #AC7356",
"*/	c #9E674E",
"=/	c #704A39",
"-/	c #553930",
";/	c #5C4036",
">/	c #AC7D61",
",/	c #D49472",
"'/	c #BD7A61",
")/	c #C88066",
"!/	c #B76955",
"~/	c #C77E63",
"{/	c #C97966",
"]/	c #FEF2F3",
"^/	c #FFDEC5",
"//	c #FFB98B",
"(/	c #FAA777",
"_/	c #F6A375",
":/	c #F29F71",
"</	c #FDA979",
"[/	c #FEAC7D",
"}/	c #FCA679",
"|/	c #ED9F78",
"1/	c #FFA47D",
"2/	c #FC9976",
"3/	c #E38667",
"4/	c #CE795D",
"5/	c #CC7B5D",
"6/	c #D08163",
"7/	c #D48462",
"8/	c #D67F5E",
"9/	c #EE9971",
"0/	c #FFAE7D",
"a/	c #FFAC7E",
"b/	c #FFA97B",
"c/	c #FFAD7E",
"d/	c #FFA87B",
"e/	c #FE9D73",
"f/	c #FEA079",
"g/	c #FEA277",
"h/	c #F8A076",
"i/	c #FBA479",
"j/	c #F49E74",
"k/	c #EB9670",
"l/	c #DF8F6A",
"m/	c #D28663",
"n/	c #CB8463",
"o/	c #C37F5F",
"p/	c #B06E53",
"q/	c #A46D51",
"r/	c #9C6950",
"s/	c #835C47",
"t/	c #704D3F",
"u/	c #85604D",
"v/	c #C68D6C",
"w/	c #B7765C",
"x/	c #945344",
"y/	c #C67C60",
"z/	c #C37D64",
"A/	c #BF765F",
"B/	c #E79B8E",
"C/	c #FFE4D4",
"D/	c #FFB88B",
"E/	c #FFB789",
"F/	c #FFB080",
"G/	c #FFAD7C",
"H/	c #FFA574",
"I/	c #FFAB7C",
"J/	c #FFB17F",
"K/	c #FCA97C",
"L/	c #F2A27A",
"M/	c #FFA078",
"N/	c #FE9A78",
"O/	c #E38565",
"P/	c #D37C62",
"Q/	c #C97C5F",
"R/	c #CC8468",
"S/	c #D38767",
"T/	c #E28E69",
"U/	c #F8A074",
"V/	c #FFA778",
"W/	c #FFAA7F",
"X/	c #FFAF84",
"Y/	c #FFAC80",
"Z/	c #FFAD80",
"`/	c #FFB383",
" (	c #FFA57C",
".(	c #FFA379",
"+(	c #FAA075",
"@(	c #F49B73",
"#(	c #EE9871",
"$(	c #E79470",
"%(	c #DB8C69",
"&(	c #CF8462",
"*(	c #C7805F",
"=(	c #BC7A5B",
"-(	c #AA6E52",
";(	c #9C684D",
">(	c #9A6A51",
",(	c #8E654F",
"'(	c #8D6853",
")(	c #A6785D",
"!(	c #C38968",
"~(	c #BB765A",
"{(	c #CE8062",
"](	c #DA8E70",
"^(	c #C47D64",
"/(	c #D57E66",
"((	c #F8D1CD",
"_(	c #FFECDE",
":(	c #FFB88A",
"<(	c #FFB285",
"[(	c #FFB082",
"}(	c #FFB181",
"|(	c #FFB381",
"1(	c #FFAC7C",
"2(	c #F8A578",
"3(	c #F7A57D",
"4(	c #FFAA85",
"5(	c #FE9475",
"6(	c #EB8468",
"7(	c #D77960",
"8(	c #C4755B",
"9(	c #B36654",
"0(	c #B76A56",
"a(	c #C4775D",
"b(	c #E39670",
"c(	c #FDA67B",
"d(	c #FFAD7F",
"e(	c #FFAE83",
"f(	c #FFAF83",
"g(	c #FFAF81",
"h(	c #FFAB81",
"i(	c #FFA67D",
"j(	c #FDA279",
"k(	c #F99F76",
"l(	c #F19A71",
"m(	c #E7926C",
"n(	c #E0916B",
"o(	c #D78C68",
"p(	c #CF8563",
"q(	c #C07B5B",
"r(	c #B47556",
"s(	c #A26A4F",
"t(	c #9A6A4F",
"u(	c #986B52",
"v(	c #936952",
"w(	c #906A53",
"x(	c #A8775D",
"y(	c #B4775C",
"z(	c #BF7A5F",
"A(	c #C98064",
"B(	c #C97F64",
"C(	c #C37B63",
"D(	c #DE9C8C",
"E(	c #FFFDFD",
"F(	c #FFF6F0",
"G(	c #FEB586",
"H(	c #FFB98A",
"I(	c #FFBC8D",
"J(	c #FFAF7F",
"K(	c #FFA878",
"L(	c #EE9F76",
"M(	c #FCA37F",
"N(	c #FFA782",
"O(	c #FE9571",
"P(	c #F08C6E",
"Q(	c #DA7B60",
"R(	c #C6745C",
"S(	c #C37359",
"T(	c #CA755A",
"U(	c #C6735A",
"V(	c #B86C56",
"W(	c #DB8966",
"X(	c #FAA278",
"Y(	c #FFA97F",
"Z(	c #FFAC82",
"`(	c #FFB185",
" _	c #FFAD83",
"._	c #FFA87D",
"+_	c #FEA278",
"@_	c #F89E75",
"#_	c #E2916C",
"$_	c #DB8C68",
"%_	c #D38564",
"&_	c #C88260",
"*_	c #B97658",
"=_	c #AB6D51",
"-_	c #9E694F",
";_	c #996B51",
">_	c #946951",
",_	c #926B54",
"'_	c #996F58",
")_	c #A27159",
"!_	c #B0765C",
"~_	c #C47E64",
"{_	c #C98065",
"]_	c #CC8673",
"^_	c #FBEDED",
"/_	c #FEBC90",
"(_	c #FFB78A",
"__	c #FFB889",
":_	c #FFB083",
"<_	c #FFA97C",
"[_	c #F59E75",
"}_	c #F29C77",
"|_	c #FE9D7B",
"1_	c #FFAD88",
"2_	c #FFA07E",
"3_	c #F59476",
"4_	c #DA8066",
"5_	c #C3705A",
"6_	c #CC785B",
"7_	c #D77D62",
"8_	c #CD745D",
"9_	c #B66551",
"0_	c #B87056",
"a_	c #DD8B65",
"b_	c #F79C73",
"c_	c #FFA77C",
"d_	c #FFAA80",
"e_	c #FFA47C",
"f_	c #FDA179",
"g_	c #F4A077",
"h_	c #EA9972",
"i_	c #DC8C67",
"j_	c #D08361",
"k_	c #CC8261",
"l_	c #C5815F",
"m_	c #B37656",
"n_	c #A46C4F",
"o_	c #A06B51",
"p_	c #9B6C53",
"q_	c #936B53",
"r_	c #8E6953",
"s_	c #9D755D",
"t_	c #794F41",
"u_	c #7A5041",
"v_	c #996551",
"w_	c #B67C63",
"x_	c #D7AA98",
"y_	c #FAEDEE",
"z_	c #FFD2B4",
"A_	c #FFBB8D",
"B_	c #FFA77D",
"C_	c #F89E74",
"D_	c #E8956F",
"E_	c #EE9E7C",
"F_	c #FD9877",
"G_	c #FFA27F",
"H_	c #FEA07E",
"I_	c #DF8569",
"J_	c #BA6A56",
"K_	c #B36954",
"L_	c #BA6E57",
"M_	c #B56752",
"N_	c #B76451",
"O_	c #AB5D4B",
"P_	c #B36651",
"Q_	c #D88C68",
"R_	c #E39069",
"S_	c #F39871",
"T_	c #FCA179",
"U_	c #FEA67C",
"V_	c #FEA57D",
"W_	c #F69D76",
"X_	c #F59D76",
"Y_	c #EF9B72",
"Z_	c #E69770",
"`_	c #D88D68",
" :	c #D08563",
".:	c #C98160",
"+:	c #BF7E5E",
"@:	c #B07355",
"#:	c #A36B50",
"$:	c #9F6E52",
"%:	c #996B52",
"&:	c #946B54",
"*:	c #936C55",
"=:	c #966D55",
"-:	c #8E5D48",
";:	c #8C5F48",
">:	c #694B3E",
",:	c #DCCAC7",
"':	c #FFEBDD",
"):	c #FEB588",
"!:	c #FEAB7F",
"~:	c #FCA77B",
"{:	c #EC9870",
"]:	c #E3926B",
"^:	c #BD7859",
"/:	c #DC886B",
"(:	c #E78D6E",
"_:	c #DB8064",
"::	c #B56B55",
"<:	c #955846",
"[:	c #7C4236",
"}:	c #77372E",
"|:	c #843F34",
"1:	c #8A493B",
"2:	c #A7614E",
"3:	c #C2755A",
"4:	c #D78B68",
"5:	c #E28E67",
"6:	c #E58F69",
"7:	c #E8906A",
"8:	c #F59972",
"9:	c #F79B75",
"0:	c #ED9671",
"a:	c #EC9671",
"b:	c #E8946E",
"c:	c #DD8E69",
"d:	c #D38A66",
"e:	c #CB8362",
"f:	c #C47F5E",
"g:	c #BD7C5B",
"h:	c #B07354",
"i:	c #A26C50",
"j:	c #9E6A51",
"k:	c #996C52",
"l:	c #986E54",
"m:	c #916F58",
"n:	c #A9775D",
"o:	c #B67C5D",
"p:	c #A57459",
"q:	c #725747",
"r:	c #EFEBEF",
"s:	c #FFBE94",
"t:	c #FFB586",
"u:	c #FBA77B",
"v:	c #F5A074",
"w:	c #EA946D",
"x:	c #EE966F",
"y:	c #ED9772",
"z:	c #B6725B",
"A:	c #AA6B53",
"B:	c #A25F4B",
"C:	c #935746",
"D:	c #81473B",
"E:	c #975445",
"F:	c #A1594A",
"G:	c #A25646",
"H:	c #A9654F",
"I:	c #BC7059",
"J:	c #C7795D",
"K:	c #D58665",
"L:	c #E28F68",
"M:	c #E59169",
"N:	c #E68E66",
"O:	c #EC936E",
"P:	c #EC9670",
"Q:	c #E9946E",
"R:	c #E3926C",
"S:	c #E2926C",
"T:	c #D98D69",
"U:	c #CF8765",
"V:	c #C88361",
"W:	c #C17D5D",
"X:	c #B97B5B",
"Y:	c #AB7053",
"Z:	c #A46D50",
"`:	c #A06D53",
" <	c #986C53",
".<	c #926A53",
"+<	c #916E59",
"@<	c #BD8366",
"#<	c #C28667",
"$<	c #B37D61",
"%<	c #6D5548",
"&<	c #F3F0F4",
"*<	c #FED3B3",
"=<	c #FEB384",
"-<	c #FDAD80",
";<	c #FAA57A",
"><	c #F29E72",
",<	c #F2996F",
"'<	c #FAA076",
")<	c #F89F77",
"!<	c #E2926E",
"~<	c #A96E55",
"{<	c #855241",
"]<	c #804C3D",
"^<	c #7C483A",
"/<	c #7E4C3D",
"(<	c #955946",
"_<	c #A46651",
":<	c #AE6E56",
"<<	c #BB755C",
"[<	c #C1785E",
"}<	c #CB8162",
"|<	c #D78A68",
"1<	c #DB8B67",
"2<	c #DF8B64",
"3<	c #E5916C",
"4<	c #E7956F",
"5<	c #E4956E",
"6<	c #E1936B",
"7<	c #D38563",
"8<	c #CC8664",
"9<	c #C68160",
"0<	c #BF805F",
"a<	c #AA7355",
"b<	c #A77254",
"c<	c #A06E54",
"d<	c #9B6D53",
"e<	c #916953",
"f<	c #95705A",
"g<	c #C58867",
"h<	c #C38465",
"i<	c #B27E62",
"j<	c #8B7366",
"k<	c #FCF9FB",
"l<	c #FFE7D3",
"m<	c #F7AF81",
"n<	c #FAAC7D",
"o<	c #F4A477",
"p<	c #F2A073",
"q<	c #EF9C71",
"r<	c #F4A179",
"s<	c #EB9D78",
"t<	c #DF9672",
"u<	c #D18969",
"v<	c #B27156",
"w<	c #905945",
"x<	c #885542",
"y<	c #8E5845",
"z<	c #99614D",
"A<	c #A56953",
"B<	c #A86C56",
"C<	c #AA6D56",
"D<	c #B3745C",
"E<	c #BF7E63",
"F<	c #C48162",
"G<	c #CA8664",
"H<	c #D58A64",
"I<	c #E49269",
"J<	c #E6936B",
"K<	c #E4926B",
"L<	c #E0906C",
"M<	c #DB8B68",
"N<	c #CE8563",
"O<	c #C88462",
"P<	c #C07F5F",
"Q<	c #BB7F5E",
"R<	c #B77B5C",
"S<	c #A47255",
"T<	c #A67256",
"U<	c #9A6C53",
"V<	c #9C725B",
"W<	c #C58665",
"X<	c #C08465",
"Y<	c #B18166",
"Z<	c #E3CCB2",
"`<	c #FFF7F0",
" [	c #F4AD81",
".[	c #F4A779",
"+[	c #F19F72",
"@[	c #E5976B",
"#[	c #E39C73",
"$[	c #E39D76",
"%[	c #D89672",
"&[	c #CF906C",
"*[	c #D08A6C",
"=[	c #C88365",
"-[	c #B27158",
";[	c #A66A52",
">[	c #9A634C",
",[	c #AC6F55",
"'[	c #B3735B",
")[	c #A97159",
"![	c #AC735B",
"~[	c #AE755C",
"{[	c #BE8063",
"][	c #C48565",
"^[	c #BF8362",
"/[	c #E0936B",
"([	c #E19169",
"_[	c #E2936A",
":[	c #DE906A",
"<[	c #D88F69",
"[[	c #CB8563",
"}[	c #C07F5E",
"|[	c #B97E5D",
"1[	c #B57C5B",
"2[	c #B57A5A",
"3[	c #AC7759",
"4[	c #A47256",
"5[	c #996A51",
"6[	c #946A52",
"7[	c #8E6B55",
"8[	c #A5775C",
"9[	c #C48666",
"0[	c #BF8565",
"a[	c #BD9077",
"b[	c #F8E7DC",
"c[	c #F6B890",
"d[	c #F3AA7B",
"e[	c #EFA275",
"f[	c #EAA173",
"g[	c #D5976E",
"h[	c #CD956E",
"i[	c #DA9D76",
"j[	c #D79872",
"k[	c #D9926F",
"l[	c #E19471",
"m[	c #D88768",
"n[	c #CA775C",
"o[	c #BA7157",
"p[	c #B5725A",
"q[	c #B6795F",
"r[	c #B57A5E",
"s[	c #B4785C",
"t[	c #B57B5E",
"u[	c #AA7458",
"v[	c #AC7758",
"w[	c #D28F67",
"x[	c #D88E66",
"y[	c #DE8F67",
"z[	c #DD9069",
"A[	c #D78E68",
"B[	c #BB7D5C",
"C[	c #BA7F5C",
"D[	c #B77D5C",
"E[	c #B57B5B",
"F[	c #9D694E",
"G[	c #9F6E53",
"H[	c #956850",
"I[	c #8E6750",
"J[	c #856651",
"K[	c #AD7B5E",
"L[	c #C58A68",
"M[	c #BD8666",
"N[	c #CFAF9A",
"O[	c #F9CCAA",
"P[	c #F2AE7F",
"Q[	c #F3A878",
"R[	c #E09D6F",
"S[	c #CA8D64",
"T[	c #AD785A",
"U[	c #C08967",
"V[	c #C18467",
"W[	c #B76E57",
"X[	c #B96753",
"Y[	c #C7705B",
"Z[	c #C7725C",
"`[	c #A35446",
" }	c #8A4238",
".}	c #823F35",
"+}	c #83443A",
"@}	c #7D443A",
"#}	c #7D463A",
"$}	c #7F4B3B",
"%}	c #6D3D30",
"&}	c #7C4B3A",
"*}	c #B47754",
"=}	c #D48D63",
"-}	c #DB9066",
";}	c #DA9069",
">}	c #CE8965",
",}	c #C18261",
"'}	c #B67C5C",
")}	c #B97F5D",
"!}	c #B77E5D",
"~}	c #B37A5B",
"{}	c #9C6A51",
"]}	c #91664E",
"^}	c #8F6851",
"/}	c #83624F",
"(}	c #B68261",
"_}	c #C38967",
":}	c #B98363",
"<}	c #D0B6A9",
"[}	c #FDDCC5",
"}}	c #F0B183",
"|}	c #F7AC7A",
"1}	c #E49D6E",
"2}	c #C3825C",
"3}	c #A1614B",
"4}	c #8B4F42",
"5}	c #8A4A41",
"6}	c #8F4941",
"7}	c #88433C",
"8}	c #863E39",
"9}	c #8E463C",
"0}	c #8B463C",
"a}	c #813E36",
"b}	c #824038",
"c}	c #853D37",
"d}	c #833A34",
"e}	c #853E36",
"f}	c #874238",
"g}	c #9D5B46",
"h}	c #A56146",
"i}	c #A76747",
"j}	c #BB7B56",
"k}	c #DC9368",
"l}	c #DC9168",
"m}	c #D38E67",
"n}	c #CA8963",
"o}	c #B87D5C",
"p}	c #BA7F5D",
"q}	c #B87F5E",
"r}	c #B17A5B",
"s}	c #A47156",
"t}	c #966850",
"u}	c #8B624C",
"v}	c #8C664F",
"w}	c #8A6550",
"x}	c #BB8564",
"y}	c #C28765",
"z}	c #B67F61",
"A}	c #D1B7AE",
"B}	c #FEEDDD",
"C}	c #EEB084",
"D}	c #F3AC7D",
"E}	c #EFA474",
"F}	c #E3986C",
"G}	c #EB976D",
"H}	c #DD8C68",
"I}	c #D38064",
"J}	c #C86455",
"K}	c #CC6554",
"L}	c #DA755F",
"M}	c #DB725D",
"N}	c #D46956",
"O}	c #CC6653",
"P}	c #C06251",
"Q}	c #B65A49",
"R}	c #B7654F",
"S}	c #BA6E55",
"T}	c #BF7659",
"U}	c #CE8360",
"V}	c #D5855E",
"W}	c #D3835B",
"X}	c #CB845A",
"Y}	c #D88E63",
"Z}	c #D68B64",
"`}	c #C38461",
" |	c #B57A5B",
".|	c #B77A5B",
"+|	c #B67E5D",
"@|	c #B47D5E",
"#|	c #B37C5C",
"$|	c #8E634B",
"%|	c #855F4A",
"&|	c #83614C",
"*|	c #996C54",
"=|	c #BF8664",
"-|	c #BE8664",
";|	c #B68263",
">|	c #D4B9AC",
",|	c #ECB68B",
"'|	c #E4A67A",
")|	c #E9A374",
"!|	c #EFA473",
"~|	c #F8A374",
"{|	c #F0A074",
"]|	c #E69A72",
"^|	c #D98A69",
"/|	c #CA7D5F",
"(|	c #BD775B",
"_|	c #B26751",
":|	c #AF644F",
"<|	c #BC7057",
"[|	c #C6795C",
"}|	c #C77C5E",
"||	c #C88362",
"1|	c #C9805E",
"2|	c #D08460",
"3|	c #DC8863",
"4|	c #E48F66",
"5|	c #DF8B62",
"6|	c #D1865D",
"7|	c #CF865D",
"8|	c #C8855D",
"9|	c #B67A58",
"0|	c #AC7658",
"a|	c #AF7959",
"b|	c #B37D5B",
"c|	c #AF7A5B",
"d|	c #AA795A",
"e|	c #9D6E54",
"f|	c #95684F",
"g|	c #8B634B",
"h|	c #835E49",
"i|	c #7E5C49",
"j|	c #AF7B5B",
"k|	c #C08764",
"l|	c #C08766",
"m|	c #B57F60",
"n|	c #E3CDC5",
"o|	c #F0CAAC",
"p|	c #DEA47A",
"q|	c #E0A173",
"r|	c #EEA473",
"s|	c #F5A574",
"t|	c #F3A174",
"u|	c #E7986F",
"v|	c #D98E68",
"w|	c #C88563",
"x|	c #B8785B",
"y|	c #A7644F",
"z|	c #A7604C",
"A|	c #B06C51",
"B|	c #B97154",
"C|	c #C57858",
"D|	c #CD7F5D",
"E|	c #DE8862",
"F|	c #E7926A",
"G|	c #EC9A6E",
"H|	c #E59167",
"I|	c #DF8D63",
"J|	c #D68A60",
"K|	c #CC845D",
"L|	c #C07E5A",
"M|	c #B47756",
"N|	c #B27858",
"O|	c #B07A5B",
"P|	c #AC765A",
"Q|	c #A47557",
"R|	c #9F7154",
"S|	c #946850",
"T|	c #8E644C",
"U|	c #89614A",
"V|	c #7B5845",
"W|	c #90654F",
"X|	c #BB8261",
"Y|	c #C38866",
"Z|	c #C08564",
"`|	c #B37E5F",
" 1	c #ECD8D8",
".1	c #FAE8D9",
"+1	c #DBA47A",
"@1	c #DFA074",
"#1	c #E9A372",
"$1	c #F0A473",
"%1	c #ED9E70",
"&1	c #ED9A6E",
"*1	c #E7976B",
"=1	c #D98B63",
"-1	c #C37A58",
";1	c #A6624D",
">1	c #A15D4A",
",1	c #AE664D",
"'1	c #C67856",
")1	c #D88660",
"!1	c #E48E67",
"~1	c #EA9168",
"{1	c #E89167",
"]1	c #E69167",
"^1	c #E69467",
"/1	c #E09266",
"(1	c #D38E63",
"_1	c #CC865F",
":1	c #C07F5A",
"<1	c #BA7D5A",
"[1	c #B87B5A",
"}1	c #AC7659",
"|1	c #A16E53",
"11	c #9D6D52",
"21	c #996C51",
"31	c #91654D",
"41	c #845D48",
"51	c #7D5843",
"61	c #775441",
"71	c #B27B5C",
"81	c #C58563",
"91	c #C68765",
"01	c #B07C5D",
"a1	c #C4A595",
"b1	c #FDFAFA",
"c1	c #DBAE89",
"d1	c #DAA176",
"e1	c #E3A373",
"f1	c #E7A06F",
"g1	c #E59B6D",
"h1	c #E69A6D",
"i1	c #EB9B6D",
"j1	c #E99B6D",
"k1	c #D5845E",
"l1	c #B2694F",
"m1	c #AB664C",
"n1	c #B7694E",
"o1	c #C97B5A",
"p1	c #E08F65",
"q1	c #E28B62",
"r1	c #E28F64",
"s1	c #DF8F65",
"t1	c #E2966A",
"u1	c #D78F65",
"v1	c #CB8A62",
"w1	c #C3835E",
"x1	c #B47656",
"y1	c #AE7756",
"z1	c #9E6D52",
"A1	c #9B6C51",
"B1	c #90664D",
"C1	c #855D48",
"D1	c #7A5541",
"E1	c #704D3D",
"F1	c #9E6C51",
"G1	c #C58763",
"H1	c #C98A68",
"I1	c #C58765",
"J1	c #BC7F5E",
"K1	c #AC785A",
"L1	c #97765F",
"M1	c #BFAC9A",
"N1	c #B9A8A6",
"O1	c #F3DDCC",
"P1	c #D49F74",
"Q1	c #DEA375",
"R1	c #E29D6D",
"S1	c #DF9667",
"T1	c #E39C6B",
"U1	c #EDA06F",
"V1	c #EA9C6D",
"W1	c #E99669",
"X1	c #D7845C",
"Y1	c #DB845E",
"Z1	c #DE8660",
"`1	c #E48E64",
" 2	c #ED976A",
".2	c #EC9668",
"+2	c #E99467",
"@2	c #E29064",
"#2	c #DF9166",
"$2	c #D58F67",
"%2	c #D08C65",
"&2	c #C28660",
"*2	c #BB7E5C",
"=2	c #B67958",
"-2	c #A87052",
";2	c #A57052",
">2	c #9D6C50",
",2	c #98694F",
"'2	c #8F634B",
")2	c #825C46",
"!2	c #75513F",
"~2	c #6C4A3B",
"{2	c #92654C",
"]2	c #C18562",
"^2	c #C88865",
"/2	c #C88765",
"(2	c #C28261",
"_2	c #A77558",
":2	c #81614E",
"<2	c #AEA39A",
"[2	c #8B7662",
"}2	c #837374",
"|2	c #F7F4F8",
"12	c #E3B38F",
"22	c #C28E66",
"32	c #DD9C6D",
"42	c #E09A6B",
"52	c #E49E6C",
"62	c #EFA26F",
"72	c #F19F6E",
"82	c #EC986B",
"92	c #E69067",
"02	c #E78E64",
"a2	c #F1956D",
"b2	c #E99068",
"c2	c #F09C70",
"d2	c #F29F70",
"e2	c #EC9C6B",
"f2	c #E49667",
"g2	c #DB9167",
"h2	c #CB845C",
"i2	c #CD8760",
"j2	c #B97F5C",
"k2	c #A87455",
"l2	c #9A6B4F",
"m2	c #A06E51",
"n2	c #9E6D50",
"o2	c #91664C",
"p2	c #8D6249",
"q2	c #805844",
"r2	c #75503D",
"s2	c #6D4939",
"t2	c #8F6148",
"u2	c #BE835F",
"v2	c #C78A65",
"w2	c #CB8D67",
"x2	c #C88864",
"y2	c #B17658",
"z2	c #A47155",
"A2	c #825F4D",
"B2	c #B4A9A1",
"C2	c #CBB49E",
"D2	c #4C3D36",
"E2	c #8E807B",
"F2	c #FEFCFE",
"G2	c #F7EBDF",
"H2	c #CC9B74",
"I2	c #D99E72",
"J2	c #E09E6C",
"K2	c #E7A170",
"L2	c #EEA472",
"M2	c #E59A6C",
"N2	c #E3936A",
"O2	c #E4946C",
"P2	c #DB8D66",
"Q2	c #E7946C",
"R2	c #E9946B",
"S2	c #E8986E",
"T2	c #E1976C",
"U2	c #D99569",
"V2	c #CF8F66",
"W2	c #BC815D",
"X2	c #A77455",
"Y2	c #AA7153",
"Z2	c #99694D",
"`2	c #94684C",
" 3	c #8F644C",
".3	c #885D45",
"+3	c #7C5440",
"@3	c #724D3C",
"#3	c #664537",
"$3	c #8E6249",
"%3	c #B9825E",
"&3	c #C68963",
"*3	c #CC8E68",
"=3	c #CA8A65",
"-3	c #C48261",
";3	c #BB7E5F",
">3	c #AE7658",
",3	c #A26E51",
"'3	c #8B644D",
")3	c #C6B4AB",
"!3	c #E4D2C1",
"~3	c #5D4B40",
"{3	c #4C3F37",
"]3	c #B9AEAF",
"^3	c #E8CAAF",
"/3	c #CD9B72",
"(3	c #DB9C6D",
"_3	c #CB9168",
":3	c #DC996A",
"<3	c #D08B61",
"[3	c #D08860",
"}3	c #CE8760",
"|3	c #D08862",
"13	c #D28862",
"23	c #D78A64",
"33	c #D48D66",
"43	c #C38663",
"53	c #B9805E",
"63	c #C18B63",
"73	c #A97655",
"83	c #926449",
"93	c #9C6B4F",
"03	c #91654B",
"a3	c #8B6147",
"b3	c #895F47",
"c3	c #885D44",
"d3	c #7F5540",
"e3	c #6C4837",
"f3	c #694536",
"g3	c #8E6147",
"h3	c #B17A59",
"i3	c #C18762",
"j3	c #C98A64",
"k3	c #C98A65",
"l3	c #C48461",
"m3	c #B77C5C",
"n3	c #AF7556",
"o3	c #A26E50",
"p3	c #8F654D",
"q3	c #DBCAC0",
"r3	c #E9D7C7",
"s3	c #6F5E51",
"t3	c #463632",
"u3	c #574B45",
"v3	c #E7DDDD",
"w3	c #FEFCF9",
"x3	c #CEA886",
"y3	c #AC805D",
"z3	c #A87A58",
"A3	c #C1895E",
"B3	c #B57A58",
"C3	c #BF7E59",
"D3	c #BB7F5A",
"E3	c #BA7A59",
"F3	c #A86C4C",
"G3	c #8F5C44",
"H3	c #9B694D",
"I3	c #936248",
"J3	c #9B6D4E",
"K3	c #896148",
"L3	c #875D45",
"M3	c #8A5F47",
"N3	c #865B44",
"O3	c #805842",
"P3	c #805740",
"Q3	c #764E3B",
"R3	c #6B4636",
"S3	c #714937",
"T3	c #97674A",
"U3	c #BD8560",
"V3	c #C68A65",
"W3	c #C68764",
"X3	c #C58562",
"Y3	c #BF8260",
"Z3	c #B87A5A",
"`3	c #B07655",
" 4	c #A16E51",
".4	c #97715D",
"+4	c #F8EBE2",
"@4	c #ECDBCD",
"#4	c #715F54",
"$4	c #3F2F2D",
"%4	c #443733",
"&4	c #726361",
"*4	c #F3EDF0",
"=4	c #FAEEE9",
"-4	c #9D7C5F",
";4	c #9A7252",
">4	c #966C4D",
",4	c #9A6A4B",
"'4	c #9E6D4D",
")4	c #915E44",
"!4	c #8B5B44",
"~4	c #855840",
"{4	c #905E44",
"]4	c #8C5B3F",
"^4	c #784F39",
"/4	c #704938",
"(4	c #744C38",
"_4	c #75503C",
":4	c #714E3A",
"<4	c #7C5842",
"[4	c #77523E",
"}4	c #78513C",
"|4	c #77503B",
"14	c #6B4435",
"24	c #81543F",
"34	c #AB7555",
"44	c #B9815E",
"54	c #BE8761",
"64	c #C48964",
"74	c #C78864",
"84	c #C48562",
"94	c #C38462",
"04	c #C58662",
"a4	c #C1805E",
"b4	c #BB7C5B",
"c4	c #AD7556",
"d4	c #A26D52",
"e4	c #BEA398",
"f4	c #FFEFE6",
"g4	c #EEDACE",
"h4	c #615047",
"i4	c #3C2C29",
"j4	c #3D2E2B",
"k4	c #493C35",
"l4	c #7D6F67",
"m4	c #F5F6F5",
"n4	c #E7D5CC",
"o4	c #826049",
"p4	c #79543C",
"q4	c #7F553C",
"r4	c #7B543C",
"s4	c #704936",
"t4	c #6C4734",
"u4	c #623E2E",
"v4	c #674330",
"w4	c #6C4531",
"x4	c #5D3B2C",
"y4	c #58382B",
"z4	c #5B3C2C",
"A4	c #54382A",
"B4	c #5C3E2F",
"C4	c #654534",
"D4	c #654535",
"E4	c #664433",
"F4	c #654232",
"G4	c #714837",
"H4	c #9A6349",
"I4	c #B77B5A",
"J4	c #BC815F",
"K4	c #C08561",
"L4	c #C38A64",
"M4	c #C38662",
"N4	c #C58561",
"O4	c #C98763",
"P4	c #C68462",
"Q4	c #C28360",
"R4	c #BA815E",
"S4	c #B07858",
"T4	c #A8745C",
"U4	c #F1E8E4",
"V4	c #FFEDE4",
"W4	c #E4D6C8",
"X4	c #4B3833",
"Y4	c #392826",
"Z4	c #392A27",
"`4	c #887A75",
" 5	c #F9F6F8",
".5	c #CAB5A4",
"+5	c #644431",
"@5	c #66422E",
"#5	c #684330",
"$5	c #56392A",
"%5	c #533527",
"&5	c #4F3022",
"*5	c #533123",
"=5	c #4B2D22",
"-5	c #43271E",
";5	c #462A21",
">5	c #422720",
",5	c #4E3127",
"'5	c #895A42",
")5	c #AE7656",
"!5	c #B97D5C",
"~5	c #BB7F5C",
"{5	c #BB7F5D",
"]5	c #BE8260",
"^5	c #BC8261",
"/5	c #C08461",
"(5	c #C48561",
"_5	c #C88562",
":5	c #C78964",
"<5	c #C38561",
"[5	c #B27859",
"}5	c #D8C0B7",
"|5	c #FFF9F2",
"15	c #D1BFB0",
"25	c #3A2725",
"35	c #362524",
"45	c #362625",
"55	c #392927",
"65	c #40312D",
"75	c #4A3E36",
"85	c #837870",
"95	c #F5F2F0",
"05	c #F4EEE7",
"a5	c #725540",
"b5	c #573B2D",
"c5	c #523527",
"d5	c #432920",
"e5	c #3A211B",
"f5	c #3F241B",
"g5	c #361E18",
"h5	c #391E19",
"i5	c #381F1A",
"j5	c #341A17",
"k5	c #3C211B",
"l5	c #5D3328",
"m5	c #875641",
"n5	c #A97152",
"o5	c #BB7E5D",
"p5	c #BD7F5D",
"q5	c #BE8563",
"r5	c #C28764",
"s5	c #C38863",
"t5	c #C28662",
"u5	c #BD815E",
"v5	c #CAA293",
"w5	c #FEFAFB",
"x5	c #FFF2EC",
"y5	c #FEEBE4",
"z5	c #9B877C",
"A5	c #372525",
"B5	c #352423",
"C5	c #362423",
"D5	c #352524",
"E5	c #382827",
"F5	c #3D2F2C",
"G5	c #463732",
"H5	c #695E5C",
"I5	c #C3B7B4",
"J5	c #F9F6F6",
"K5	c #A0866E",
"L5	c #50362B",
"M5	c #442B21",
"N5	c #3D241C",
"O5	c #37201A",
"P5	c #341D18",
"Q5	c #321C18",
"R5	c #341B16",
"S5	c #321916",
"T5	c #341B18",
"U5	c #361C18",
"V5	c #42231D",
"W5	c #693F30",
"X5	c #A16C4F",
"Y5	c #B37858",
"Z5	c #B77858",
"`5	c #B57859",
" 6	c #B57658",
".6	c #B77959",
"+6	c #B97A5A",
"@6	c #BD7F5C",
"#6	c #BF825F",
"$6	c #C58764",
"%6	c #C68865",
"&6	c #C79984",
"*6	c #FCF8F8",
"=6	c #FFFBF9",
"-6	c #FFF4EC",
";6	c #F6E5DC",
">6	c #58443E",
",6	c #362323",
"'6	c #342322",
")6	c #342222",
"!6	c #352323",
"~6	c #382826",
"{6	c #3B2C2A",
"]6	c #41332F",
"^6	c #483A34",
"/6	c #594D47",
"(6	c #9D9494",
"_6	c #E3DDDD",
":6	c #F7F5F4",
"<6	c #AE9B89",
"[6	c #50392D",
"}6	c #432A22",
"|6	c #402720",
"16	c #37221D",
"26	c #37201C",
"36	c #442921",
"46	c #38211C",
"56	c #3D241E",
"66	c #432921",
"76	c #4C2C23",
"86	c #6D4131",
"96	c #955E46",
"06	c #AE7054",
"a6	c #B37456",
"b6	c #B17356",
"c6	c #AB6F52",
"d6	c #AF7355",
"e6	c #B47858",
"f6	c #BB7A59",
"g6	c #BD7E5C",
"h6	c #BF815F",
"i6	c #C68965",
"j6	c #C48966",
"k6	c #C58865",
"l6	c #C6947E",
"m6	c #FAF4F3",
"n6	c #FFFAF8",
"o6	c #CCBBAE",
"p6	c #382422",
"q6	c #352221",
"r6	c #332120",
"s6	c #332221",
"t6	c #352523",
"u6	c #372725",
"v6	c #3E2F2B",
"w6	c #3E302C",
"x6	c #423631",
"y6	c #4A3D35",
"z6	c #6A5B53",
"A6	c #9C928F",
"B6	c #CECACA",
"C6	c #FAFAF9",
"D6	c #FBFAF9",
"E6	c #CCC4C0",
"F6	c #8D7A74",
"G6	c #6A5245",
"H6	c #AA968F",
"I6	c #C5A28B",
"J6	c #8A634A",
"K6	c #895F44",
"L6	c #895D41",
"M6	c #7F563D",
"N6	c #78543F",
"O6	c #79513B",
"P6	c #6D4936",
"Q6	c #754C37",
"R6	c #774B38",
"S6	c #A5694D",
"T6	c #B27456",
"U6	c #AC6F53",
"V6	c #A76F53",
"W6	c #A96F52",
"X6	c #AC7355",
"Y6	c #BE7C5C",
"Z6	c #BF7D5C",
"`6	c #C1815F",
" 7	c #C08463",
".7	c #CA8B68",
"+7	c #C78A66",
"@7	c #C79982",
"#7	c #FAF3F2",
"$7	c #FEF1EA",
"%7	c #7F6A61",
"&7	c #362221",
"*7	c #342120",
"=7	c #332121",
"-7	c #342221",
";7	c #352322",
">7	c #362624",
",7	c #372826",
"'7	c #362725",
")7	c #382A27",
"!7	c #3C2E2A",
"~7	c #40332E",
"{7	c #453631",
"]7	c #483A33",
"^7	c #61514A",
"/7	c #998D88",
"(7	c #CFCACA",
"_7	c #F9F8F9",
":7	c #E1D7D2",
"<7	c #A18E88",
"[7	c #5E4842",
"}7	c #4B352E",
"|7	c #584239",
"17	c #4D3831",
"27	c #B29C97",
"37	c #F4D9C6",
"47	c #976A4F",
"57	c #BC8861",
"67	c #AC7B58",
"77	c #AC7B57",
"87	c #9B6D4F",
"97	c #95684D",
"07	c #8E6348",
"a7	c #906146",
"b7	c #946349",
"c7	c #A0694D",
"d7	c #AD7254",
"e7	c #AE7255",
"f7	c #A86F52",
"g7	c #A77052",
"h7	c #A87154",
"i7	c #B07759",
"j7	c #B97B5C",
"k7	c #C08563",
"l7	c #C98967",
"m7	c #C88C68",
"n7	c #CC9F8B",
"o7	c #FAF6F6",
"p7	c #FFFAF7",
"q7	c #E8DACE",
"r7	c #402A26",
"s7	c #34201F",
"t7	c #33201F",
"u7	c #332020",
"v7	c #342321",
"w7	c #322221",
"x7	c #342523",
"y7	c #352625",
"z7	c #3B2C29",
"A7	c #3D2F2B",
"B7	c #453530",
"C7	c #473933",
"D7	c #584B46",
"E7	c #8F837B",
"F7	c #C8BFBB",
"G7	c #F3EFED",
"H7	c #EDE3DF",
"I7	c #B1A39E",
"J7	c #6C5B54",
"K7	c #49322D",
"L7	c #462F29",
"M7	c #48312C",
"N7	c #4D3931",
"O7	c #4F3932",
"P7	c #452F2A",
"Q7	c #B6A19D",
"R7	c #FEF3EE",
"S7	c #A8816B",
"T7	c #C79167",
"U7	c #C38C64",
"V7	c #BD8860",
"W7	c #BC8560",
"X7	c #AF7D5B",
"Y7	c #A67657",
"Z7	c #A37254",
"`7	c #A26F51",
" 8	c #9B664C",
".8	c #986247",
"+8	c #986148",
"@8	c #9D664C",
"#8	c #A56F52",
"$8	c #AE7759",
"%8	c #B3795A",
"&8	c #B87859",
"*8	c #C28663",
"=8	c #C78664",
"-8	c #CEA594",
";8	c #FDFAF9",
">8	c #FFF8F5",
",8	c #A39184",
"'8	c #331F1F",
")8	c #321F1E",
"!8	c #32201F",
"~8	c #342020",
"{8	c #392926",
"]8	c #3B2A27",
"^8	c #3C2B28",
"/8	c #3C2D29",
"(8	c #3D2F2A",
"_8	c #443631",
":8	c #493A34",
"<8	c #554742",
"[8	c #837976",
"}8	c #C0B8B4",
"|8	c #F0E9E7",
"18	c #F5EFED",
"28	c #B2A9A4",
"38	c #6E5C56",
"48	c #49332D",
"58	c #432E2A",
"68	c #412B27",
"78	c #3F2926",
"88	c #49352F",
"98	c #48322D",
"08	c #412A27",
"a8	c #BAA4A2",
"b8	c #E6D3CA",
"c8	c #AD7A56",
"d8	c #DB9F74",
"e8	c #D3976B",
"f8	c #CD9469",
"g8	c #C89167",
"h8	c #B8825E",
"i8	c #AE7959",
"j8	c #AA7758",
"k8	c #A47153",
"l8	c #9D6A4C",
"m8	c #9C664B",
"n8	c #A56E50",
"o8	c #AA7254",
"p8	c #AE7557",
"q8	c #BC7B5A",
"r8	c #C0805D",
"s8	c #C28460",
"t8	c #D6B1A2",
"u8	c #FEFBFB",
"v8	c #FFFBFE",
"w8	c #F9F0EB",
"x8	c #553E37",
"y8	c #341F1E",
"z8	c #321E1E",
"A8	c #331F1E",
"B8	c #311E1D",
"C8	c #342220",
"D8	c #2E1E1D",
"E8	c #322121",
"F8	c #382725",
"G8	c #3B2B28",
"H8	c #3D2C29",
"I8	c #41312D",
"J8	c #443430",
"K8	c #493834",
"L8	c #4C3C37",
"M8	c #54453F",
"N8	c #756963",
"O8	c #A8A2A0",
"P8	c #E5DFDC",
"Q8	c #FDFCFB",
"R8	c #D3CDCB",
"S8	c #8A7A71",
"T8	c #4F3830",
"U8	c #43302A",
"V8	c #422B27",
"W8	c #3F2925",
"X8	c #3D2824",
"Y8	c #3E2723",
"Z8	c #3E2825",
"`8	c #46302B",
" 9	c #47302C",
".9	c #452E29",
"+9	c #422A26",
"@9	c #BCABA6",
"#9	c #BE9C88",
"$9	c #CC8F65",
"%9	c #DE9D6F",
"&9	c #D79B6E",
"*9	c #D1966B",
"=9	c #C89066",
"-9	c #B07A59",
";9	c #AA7354",
">9	c #A97354",
",9	c #AA7455",
"'9	c #AF7659",
")9	c #B5785A",
"!9	c #BA7A5B",
"~9	c #BE7D5D",
"{9	c #C38360",
"]9	c #BF8563",
"^9	c #D9B8AA",
"/9	c #FFFAFD",
"(9	c #C7B8AB",
"_9	c #331E1E",
":9	c #321E1D",
"<9	c #321D1D",
"[9	c #311D1D",
"}9	c #352120",
"|9	c #352220",
"19	c #372523",
"29	c #392725",
"39	c #3B2926",
"49	c #3D2C2A",
"59	c #3F2E2B",
"69	c #402F2B",
"79	c #42312E",
"89	c #433330",
"99	c #453632",
"09	c #483835",
"a9	c #4B3C39",
"b9	c #56443F",
"c9	c #EFECEA",
"d9	c #B3A49F",
"e9	c #6B554D",
"f9	c #47322C",
"g9	c #402A25",
"h9	c #3D2723",
"i9	c #3D2623",
"j9	c #3B2422",
"k9	c #3C2523",
"l9	c #432C29",
"m9	c #452D29",
"n9	c #422926",
"o9	c #412925",
"p9	c #C2B5B3",
"q9	c #FCF7F5",
"r9	c #BC8C71",
"s9	c #DB9D6F",
"t9	c #DD9D71",
"u9	c #D99B6F",
"v9	c #D0976C",
"w9	c #CA9269",
"x9	c #B37E5B",
"y9	c #B37D5A",
"z9	c #AF7A5A",
"A9	c #B17959",
"B9	c #B57759",
"C9	c #BA7C5B",
"D9	c #BC7E5C",
"E9	c #BF825E",
"F9	c #DDC3B6",
"G9	c #FEF9F7",
"H9	c #7B665C",
"I9	c #311C1C",
"J9	c #321C1C",
"K9	c #311D1C",
"L9	c #331E1D",
"M9	c #34201E",
"N9	c #35211E",
"O9	c #35211F",
"P9	c #2F1D1C",
"Q9	c #33211F",
"R9	c #362523",
"S9	c #392625",
"T9	c #3A2825",
"U9	c #3B2826",
"V9	c #3C2A27",
"W9	c #3D2B29",
"X9	c #3E2C2A",
"Y9	c #3F2E2C",
"Z9	c #412F2D",
"`9	c #433130",
" 0	c #453332",
".0	c #FDFAF8",
"+0	c #D0C2BC",
"@0	c #89766F",
"#0	c #4E3C35",
"$0	c #442F29",
"%0	c #422D28",
"&0	c #3E2824",
"*0	c #3C2724",
"=0	c #3C2623",
"-0	c #3C2622",
";0	c #3B2421",
">0	c #3B2322",
",0	c #3F2825",
"'0	c #412A26",
")0	c #422A27",
"!0	c #432B27",
"~0	c #3F2824",
"{0	c #C8BCBB",
"]0	c #F4EAE6",
"^0	c #BF8765",
"/0	c #E0A072",
"(0	c #DA9D6F",
"_0	c #D4966C",
":0	c #CD946A",
"<0	c #C79068",
"[0	c #B7805C",
"}0	c #AA7757",
"|0	c #B37E5D",
"10	c #B37B5C",
"20	c #B2795A",
"30	c #B47759",
"40	c #B67959",
"50	c #BA7D5C",
"60	c #B88163",
"70	c #E7D1CB",
"80	c #E6DED3",
"90	c #3F2924",
"00	c #321D1C",
"a0	c #321C1B",
"b0	c #341D1C",
"c0	c #331E1C",
"d0	c #341E1D",
"e0	c #35201E",
"f0	c #2F1C1B",
"g0	c #362321",
"h0	c #372322",
"i0	c #382523",
"j0	c #392623",
"k0	c #382624",
"l0	c #3C2927",
"m0	c #3C2A28",
"n0	c #3C2B2A",
"o0	c #3F2C2A",
"p0	c #402D2C",
"q0	c #DACAC4",
"r0	c #948884",
"s0	c #5A4A43",
"t0	c #44322B",
"u0	c #422E2A",
"v0	c #3C2723",
"w0	c #3C2522",
"x0	c #3A2220",
"y0	c #402825",
"z0	c #3D2422",
"A0	c #D4C8C6",
"B0	c #EDDAD0",
"C0	c #C88C67",
"D0	c #DF9E71",
"E0	c #D5986B",
"F0	c #CE946A",
"G0	c #CA8F69",
"H0	c #C08762",
"I0	c #B37C5B",
"J0	c #B17859",
"K0	c #B17759",
"L0	c #AF7557",
"M0	c #AC7455",
"N0	c #AF7758",
"O0	c #BD9079",
"P0	c #F3E9E6",
"Q0	c #FEF5F4",
"R0	c #A08F83",
"S0	c #331D1C",
"T0	c #351E1D",
"U0	c #341E1C",
"V0	c #36201E",
"W0	c #2E1B1A",
"X0	c #301D1C",
"Y0	c #33201E",
"Z0	c #382322",
"`0	c #372422",
" a	c #382524",
".a	c #392524",
"+a	c #392624",
"@a	c #3C2826",
"#a	c #3C2827",
"$a	c #3D2928",
"%a	c #E1DAD8",
"&a	c #998B87",
"*a	c #5D4A41",
"=a	c #44322C",
"-a	c #44302A",
";a	c #3F2C27",
">a	c #3B2522",
",a	c #39231F",
"'a	c #39221F",
")a	c #3B2320",
"!a	c #3E2623",
"~a	c #3F2724",
"{a	c #3B2625",
"]a	c #E3DAD7",
"^a	c #E5CBB8",
"/a	c #D1966C",
"(a	c #DA996D",
"_a	c #D39469",
":a	c #C98D67",
"<a	c #AD7456",
"[a	c #AD7557",
"}a	c #AB7455",
"|a	c #A87355",
"1a	c #CBAC9D",
"2a	c #FDF9F9",
"3a	c #FFF7F5",
"4a	c #E9E0DA",
"5a	c #59463D",
"6a	c #331D1B",
"7a	c #331C1B",
"8a	c #341D1B",
"9a	c #341C1C",
"0a	c #351F1D",
"aa	c #341F1D",
"ba	c #34201D",
"ca	c #36201F",
"da	c #362220",
"ea	c #372321",
"fa	c #362322",
"ga	c #392523",
"ha	c #EBE8E6",
"ia	c #8B7B73",
"ja	c #4C372F",
"ka	c #402D27",
"la	c #3E2A26",
"ma	c #3B2622",
"na	c #3A2321",
"oa	c #392321",
"pa	c #392220",
"qa	c #38211F",
"ra	c #3A221F",
"sa	c #39211E",
"ta	c #392320",
"ua	c #3C2422",
"va	c #3D2522",
"wa	c #3D2523",
"xa	c #3E2522",
"ya	c #3D2D2A",
"za	c #E8E1DF",
"Aa	c #E8CDBC",
"Ba	c #CF9069",
"Ca	c #CE8E66",
"Da	c #CA8B66",
"Ea	c #C48864",
"Fa	c #AF795A",
"Ga	c #AE7B60",
"Ha	c #E2CEC6",
"Ia	c #FFFBFA",
"Ja	c #FCF1ED",
"Ka	c #BDB3A8",
"La	c #361E1D",
"Ma	c #341C1B",
"Na	c #351D1D",
"Oa	c #341C1A",
"Pa	c #331C1C",
"Qa	c #351F1C",
"Ra	c #37211F",
"Sa	c #2F1B1A",
"Ta	c #35201F",
"Ua	c #36211F",
"Va	c #372220",
"Wa	c #372221",
"Xa	c #372323",
"Ya	c #382423",
"Za	c #392424",
"`a	c #382424",
" b	c #B7ABA4",
".b	c #3C2925",
"+b	c #3A2622",
"@b	c #392522",
"#b	c #382421",
"$b	c #38221F",
"%b	c #37211E",
"&b	c #38211E",
"*b	c #38201E",
"=b	c #39211F",
"-b	c #3A2320",
";b	c #3C2421",
">b	c #3C2320",
",b	c #3D2421",
"'b	c #3F302F",
")b	c #E5DCDA",
"!b	c #F2DDD1",
"~b	c #CC906D",
"{b	c #C08260",
"]b	c #BD815F",
"^b	c #BA7F5E",
"/b	c #B47D5C",
"(b	c #C49C88",
"_b	c #F6EDE9",
":b	c #FFFBFD",
"<b	c #FFF7F4",
"[b	c #E8DCD7",
"}b	c #7D6D61",
"|b	c #361D1C",
"1b	c #351D1B",
"2b	c #331C1A",
"3b	c #351E1C",
"4b	c #371F1D",
"5b	c #361F1E",
"6b	c #371F1E",
"7b	c #311A19",
"8b	c #301C1B",
"9b	c #362120",
"0b	c #372222",
"ab	c #E5DDD8",
"bb	c #776761",
"cb	c #44302B",
"db	c #3F2D28",
"eb	c #382522",
"fb	c #372320",
"gb	c #382320",
"hb	c #361F1D",
"ib	c #37201D",
"jb	c #3A211E",
"kb	c #39221E",
"lb	c #3E2521",
"mb	c #3C2321",
"nb	c #423735",
"ob	c #DDD5D0",
"pb	c #F9EFEA",
"qb	c #CE987D",
"rb	c #B97859",
"sb	c #BF876B",
"tb	c #E5CBBE",
"ub	c #FFF9F9",
"vb	c #FAEFE9",
"wb	c #C9C1B9",
"xb	c #351C1B",
"yb	c #341D1A",
"zb	c #361E1C",
"Ab	c #37201E",
"Bb	c #301918",
"Cb	c #311B1A",
"Db	c #351F1F",
"Eb	c #372120",
"Fb	c #362121",
"Gb	c #372121",
"Hb	c #FAF6F5",
"Ib	c #A0958E",
"Jb	c #4A3831",
"Kb	c #402D28",
"Lb	c #3E2A25",
"Mb	c #36221F",
"Nb	c #37221F",
"Ob	c #37221E",
"Pb	c #361F1C",
"Qb	c #371F1C",
"Rb	c #36201D",
"Sb	c #3B231F",
"Tb	c #3A2420",
"Ub	c #504644",
"Vb	c #D6CEC9",
"Wb	c #E4D6D6",
"Xb	c #F1E1DF",
"Yb	c #E9D4C5",
"Zb	c #E6CEC2",
"`b	c #FBF7F7",
" c	c #FFF7F3",
".c	c #E3DAD3",
"+c	c #92837A",
"@c	c #351D1C",
"#c	c #341B1A",
"$c	c #381F1E",
"%c	c #381F1D",
"&c	c #2E1816",
"*c	c #351F1E",
"=c	c #E4DFDD",
"-c	c #64514B",
";c	c #412E28",
">c	c #3F2B26",
",c	c #382420",
"'c	c #36211E",
")c	c #371E1C",
"!c	c #38201D",
"~c	c #38211D",
"{c	c #3A211F",
"]c	c #3B221E",
"^c	c #514744",
"/c	c #CEC6C0",
"(c	c #C3B5B4",
"_c	c #978C86",
":c	c #B0A39F",
"<c	c #90847E",
"[c	c #71625B",
"}c	c #DFD7DA",
"|c	c #FFF9FB",
"1c	c #FAEFEB",
"2c	c #CCC8C2",
"3c	c #553D35",
"4c	c #331B19",
"5c	c #2D1615",
"6c	c #301A19",
"7c	c #341D1D",
"8c	c #FDFDFC",
"9c	c #C3BCB7",
"0c	c #54423A",
"ac	c #3D2B26",
"bc	c #3B2824",
"cc	c #3A2421",
"dc	c #39201E",
"ec	c #3A221E",
"fc	c #4E4340",
"gc	c #C7BFB7",
"hc	c #CEC4BF",
"ic	c #2B1C18",
"jc	c #281A19",
"kc	c #2A1E1B",
"lc	c #6A5D60",
"mc	c #FEFCFD",
"nc	c #E6DFD8",
"oc	c #ACA096",
"pc	c #361D1B",
"qc	c #361E1B",
"rc	c #2C1515",
"sc	c #341E1B",
"tc	c #351E1E",
"uc	c #F8F6F5",
"vc	c #84736D",
"wc	c #402E28",
"xc	c #39201D",
"yc	c #473C3B",
"zc	c #BBB4AB",
"Ac	c #EEE7E4",
"Bc	c #3A2B26",
"Cc	c #42352E",
"Dc	c #433932",
"Ec	c #42332C",
"Fc	c #3E322B",
"Gc	c #BCADB0",
"Hc	c #FFF7F6",
"Ic	c #D9D2CD",
"Jc	c #6D5950",
"Kc	c #341B19",
"Lc	c #351C1A",
"Mc	c #371D1B",
"Nc	c #361C1A",
"Oc	c #2C1513",
"Pc	c #3D2A25",
"Qc	c #382521",
"Rc	c #372420",
"Sc	c #382321",
"Tc	c #38201C",
"Uc	c #381F1C",
"Vc	c #391F1D",
"Wc	c #483938",
"Xc	c #B0A99F",
"Yc	c #FFFCFC",
"Zc	c #FEFEFD",
"`c	c #6F5D59",
" d	c #3A2E2A",
".d	c #463A33",
"+d	c #473934",
"@d	c #41332D",
"#d	c #483931",
"$d	c #463931",
"%d	c #493E3C",
"&d	c #ECE6E7",
"*d	c #F6EDEB",
"=d	c #CBC0B6",
"-d	c #3E2320",
";d	c #361C1B",
">d	c #361D1A",
",d	c #351D1A",
"'d	c #2C1413",
")d	c #321A18",
"!d	c #321B19",
"~d	c #331A19",
"{d	c #321B1A",
"]d	c #311B19",
"^d	c #321A1A",
"/d	c #9D908E",
"(d	c #392622",
"_d	c #36221E",
":d	c #381E1C",
"<d	c #3A211D",
"[d	c #42302F",
"}d	c #A69F95",
"|d	c #C5BBB5",
"1d	c #261917",
"2d	c #3D302C",
"3d	c #473931",
"4d	c #4F3F37",
"5d	c #473731",
"6d	c #4B3C34",
"7d	c #44342D",
"8d	c #43342D",
"9d	c #76686A",
"0d	c #F6EBE8",
"ad	c #968074",
"bd	c #351C19",
"cd	c #351B19",
"dd	c #2F1817",
"ed	c #321918",
"fd	c #321A19",
"gd	c #371E1D",
"hd	c #E4E1E0",
"id	c #43322D",
"jd	c #36211D",
"kd	c #351E1B",
"ld	c #381E1B",
"md	c #483B3A",
"nd	c #A6A198",
"od	c #FEFCFB",
"pd	c #74655E",
"qd	c #291C19",
"rd	c #332521",
"sd	c #40312A",
"td	c #453A34",
"ud	c #473831",
"vd	c #45362D",
"wd	c #44362D",
"xd	c #3E2F29",
"yd	c #392A26",
"zd	c #ADA2A8",
"Ad	c #F9F2EC",
"Bd	c #4D332D",
"Cd	c #351B1A",
"Dd	c #2C1312",
"Ed	c #301817",
"Fd	c #331A18",
"Gd	c #311917",
"Hd	c #331918",
"Id	c #9F938F",
"Jd	c #38231F",
"Kd	c #331F1D",
"Ld	c #371E1B",
"Md	c #4D3F3F",
"Nd	c #A8A399",
"Od	c #FFF7F2",
"Pd	c #D1C8C2",
"Qd	c #928F88",
"Rd	c #342724",
"Sd	c #30221D",
"Td	c #392C25",
"Ud	c #3C2D26",
"Vd	c #40332B",
"Wd	c #41322B",
"Xd	c #44362E",
"Yd	c #3E3029",
"Zd	c #3E312D",
"`d	c #3C2E2C",
" e	c #E1DEE2",
".e	c #BBAA9E",
"+e	c #371D1A",
"@e	c #361C19",
"#e	c #2B1313",
"$e	c #2F1716",
"%e	c #321917",
"&e	c #311918",
"*e	c #6E5D59",
"=e	c #35201C",
"-e	c #35211D",
";e	c #331C19",
">e	c #4F4342",
",e	c #AAA69D",
"'e	c #FFF7F1",
")e	c #A59C93",
"!e	c #ABA7A1",
"~e	c #6B5F5A",
"{e	c #30231D",
"]e	c #332622",
"^e	c #392B25",
"/e	c #463932",
"(e	c #3D322B",
"_e	c #3D2F28",
":e	c #3E312A",
"<e	c #352722",
"[e	c #2F221E",
"}e	c #615456",
"|e	c #FCFBFC",
"1e	c #FFFCFA",
"2e	c #684F45",
"3e	c #351B18",
"4e	c #2E1615",
"5e	c #321817",
"6e	c #311817",
"7e	c #301917",
"8e	c #4D3C3D",
"9e	c #331F1C",
"0e	c #341F1C",
"ae	c #341C19",
"be	c #371E1A",
"ce	c #534645",
"de	c #AEAAA3",
"ee	c #FEF5EE",
"fe	c #EBE5DE",
"ge	c #A09B96",
"he	c #B2ADA7",
"ie	c #A59F97",
"je	c #382A26",
"ke	c #362924",
"le	c #40342E",
"me	c #463830",
"ne	c #41342C",
"oe	c #3E312C",
"pe	c #312524",
"qe	c #251716",
"re	c #A0979B",
"se	c #D8CBC0",
"te	c #3C221F",
"ue	c #371C1A",
"ve	c #341A18",
"we	c #2C1212",
"xe	c #2D1515",
"ye	c #311916",
"ze	c #321816",
"Ae	c #301716",
"Be	c #2E1715",
"Ce	c #321818",
"De	c #FAF8F5",
"Ee	c #43312E",
"Fe	c #331F1B",
"Ge	c #331E1B",
"He	c #544644",
"Ie	c #AFAEA7",
"Je	c #FDF3E9",
"Ke	c #C6BEB6",
"Le	c #B5AFA9",
"Me	c #B7B0A9",
"Ne	c #62554D",
"Oe	c #352521",
"Pe	c #41332B",
"Qe	c #2C1F1D",
"Re	c #241616",
"Se	c #2C2021",
"Te	c #E2DBDD",
"Ue	c #FFFDFC",
"Ve	c #887064",
"We	c #3B211F",
"Xe	c #351A18",
"Ye	c #351A19",
"Ze	c #361B19",
"`e	c #2D1311",
" f	c #2C1414",
".f	c #301715",
"+f	c #2F1715",
"@f	c #EBEEF0",
"#f	c #402C28",
"$f	c #301816",
"%f	c #564848",
"&f	c #B3AEA8",
"*f	c #FCF2EA",
"=f	c #FBF9F4",
"-f	c #AFA7A2",
";f	c #B2ACA7",
">f	c #B8B2AB",
",f	c #C2B8B1",
"'f	c #92857C",
")f	c #342823",
"!f	c #41342D",
"~f	c #46372F",
"{f	c #40322A",
"]f	c #3C2E27",
"^f	c #231415",
"/f	c #4E4C4F",
"(f	c #B2ADAC",
"_f	c #FDFBFC",
":f	c #EEE5DC",
"<f	c #452B25",
"[f	c #291112",
"}f	c #2F1615",
"|f	c #341A1A",
"1f	c #D7D6DA",
"2f	c #3C2722",
"3f	c #311D1B",
"4f	c #371C19",
"5f	c #544745",
"6f	c #AAA7A1",
"7f	c #FAF0E6",
"8f	c #E0D7CE",
"9f	c #BEB5B1",
"0f	c #C9BFBA",
"af	c #E8DCD6",
"bf	c #C1B7A9",
"cf	c #342621",
"df	c #40342D",
"ef	c #43332D",
"ff	c #493B32",
"gf	c #392C26",
"hf	c #372A26",
"if	c #2F211E",
"jf	c #2E201C",
"kf	c #271A19",
"lf	c #241719",
"mf	c #7E7E7D",
"nf	c #E5E1DA",
"of	c #EBE1DD",
"pf	c #A9968B",
"qf	c #361B1A",
"rf	c #2C1211",
"sf	c #260F10",
"tf	c #2E1514",
"uf	c #2D1513",
"vf	c #2F1513",
"wf	c #311816",
"xf	c #341A19",
"yf	c #B2AEB0",
"zf	c #301B19",
"Af	c #321E1C",
"Bf	c #321C1A",
"Cf	c #36201C",
"Df	c #37211D",
"Ef	c #2D1614",
"Ff	c #A09D97",
"Gf	c #F6ECE1",
"Hf	c #CABFB7",
"If	c #E8E2DD",
"Jf	c #FAF0E7",
"Kf	c #F9ECE2",
"Lf	c #FEF7F0",
"Mf	c #CFC6BC",
"Nf	c #342825",
"Of	c #493C34",
"Pf	c #44352E",
"Qf	c #33241F",
"Rf	c #2C1D1A",
"Sf	c #534F54",
"Tf	c #A2A09D",
"Uf	c #F5ECE3",
"Vf	c #F5EEE5",
"Wf	c #F8F4F4",
"Xf	c #FCFAF5",
"Yf	c #5C4238",
"Zf	c #2E1413",
"`f	c #250F0E",
" g	c #2D1413",
".g	c #301615",
"+g	c #341919",
"@g	c #897D7B",
"#g	c #2E1917",
"$g	c #331D1A",
"%g	c #331917",
"&g	c #351C18",
"*g	c #504342",
"=g	c #939189",
"-g	c #EFE7D8",
";g	c #E7DFDC",
">g	c #FFFDF5",
",g	c #FFF6EA",
"'g	c #FCEEE2",
")g	c #FEF6EF",
"!g	c #B9ACA6",
"~g	c #3A2E28",
"{g	c #42362F",
"]g	c #382A24",
"^g	c #2D201D",
"/g	c #281A18",
"(g	c #2B1C19",
"_g	c #291D1F",
":g	c #8E8D8E",
"<g	c #D1CFC9",
"[g	c #F9F0E7",
"}g	c #FFFBF2",
"|g	c #F4EDE2",
"1g	c #D0C3B9",
"2g	c #351A17",
"3g	c #301614",
"4g	c #240D0E",
"5g	c #2E1412",
"6g	c #2F1614",
"7g	c #FCFAFB",
"8g	c #53403C",
"9g	c #321B18",
"0g	c #2E1613",
"ag	c #4E4242",
"bg	c #8C8A84",
"cg	c #E7DACD",
"dg	c #FFF9EE",
"eg	c #FDF0E5",
"fg	c #8F8179",
"gg	c #322420",
"hg	c #2F211D",
"ig	c #2B1D1A",
"jg	c #251717",
"kg	c #56565B",
"lg	c #AAA3A0",
"mg	c #F1EFE9",
"ng	c #FEFBF5",
"og	c #FFFCF5",
"pg	c #FFFAF1",
"qg	c #836F62",
"rg	c #341816",
"sg	c #2E1311",
"tg	c #230C0C",
"ug	c #2C1412",
"vg	c #341918",
"wg	c #CFCBCB",
"xg	c #3D2A24",
"yg	c #2F1918",
"zg	c #2F1A17",
"Ag	c #321C19",
"Bg	c #2E1714",
"Cg	c #2E1614",
"Dg	c #331916",
"Eg	c #331A16",
"Fg	c #331A17",
"Gg	c #341C18",
"Hg	c #4E4040",
"Ig	c #918C85",
"Jg	c #E6DACF",
"Kg	c #FFFDF6",
"Lg	c #FFFAEF",
"Mg	c #FEF3E8",
"Ng	c #FFF6EF",
"Og	c #998A7F",
"Pg	c #322621",
"Qg	c #30221E",
"Rg	c #352522",
"Sg	c #2F1F1E",
"Tg	c #2F211F",
"Ug	c #241716",
"Vg	c #979BA0",
"Wg	c #B6B2AE",
"Xg	c #FEFCF7",
"Yg	c #FFFCF7",
"Zg	c #FFFCF4",
"`g	c #F6EDDF",
" h	c #472C24",
".h	c #361D19",
"+h	c #341917",
"@h	c #331817",
"#h	c #301413",
"$h	c #270D0C",
"%h	c #21090A",
"&h	c #270F0F",
"*h	c #2E1513",
"=h	c #8C8585",
"-h	c #311B18",
";h	c #361E1A",
">h	c #4B3C3B",
",h	c #9E9892",
"'h	c #FFFDF4",
")h	c #FFFCF1",
"!h	c #FFF8EC",
"~h	c #F6F1E4",
"{h	c #4D3E35",
"]h	c #372A27",
"^h	c #3C302B",
"/h	c #2F201F",
"(h	c #3C363D",
"_h	c #BCC0C0",
":h	c #CCC6C3",
"<h	c #FEF8EF",
"[h	c #FDF8F2",
"}h	c #BBAA99",
"|h	c #311815",
"1h	c #220909",
"2h	c #210B0C",
"3h	c #2A1210",
"4h	c #331816",
"5h	c #5A4B48",
"6h	c #311A18",
"7h	c #2C1614",
"8h	c #341D19",
"9h	c #443333",
"0h	c #B5ADA4",
"ah	c #FCF2E5",
"bh	c #FFFEF5",
"ch	c #FFFEF4",
"dh	c #FFFCEF",
"eh	c #FFF8EA",
"fh	c #AA9A8D",
"gh	c #392C24",
"hh	c #3B2E26",
"ih	c #3F332C",
"jh	c #3F322B",
"kh	c #41322D",
"lh	c #3B2F2B",
"mh	c #352724",
"nh	c #69676A",
"oh	c #C1BCBC",
"ph	c #D8D4CE",
"qh	c #FAF0E8",
"rh	c #FDF6EE",
"sh	c #FBF6EC",
"th	c #6F574A",
"uh	c #2F1613",
"vh	c #20080A",
"wh	c #260F0E",
"xh	c #2C1313",
"yh	c #2F1514",
"zh	c #311716",
"Ah	c #321717",
"Bh	c #EFEBED",
"Ch	c #42302B",
"Dh	c #2A1413",
"Eh	c #361F1B",
"Fh	c #443332",
"Gh	c #C5BEB6",
"Hh	c #FDF4E5",
"Ih	c #FFFDF2",
"Jh	c #FFFBEB",
"Kh	c #FBF2E4",
"Lh	c #524138",
"Mh	c #362923",
"Nh	c #3A2B25",
"Oh	c #3A2D27",
"Ph	c #3C2F28",
"Qh	c #3C2D2B",
"Rh	c #30211E",
"Sh	c #392E32",
"Th	c #B4B2AD",
"Uh	c #E1DDD7",
"Vh	c #F0E5DD",
"Wh	c #FDF8F0",
"Xh	c #E5DBCB",
"Yh	c #361B18",
"Zh	c #230909",
"`h	c #210B0B",
" i	c #2A1211",
".i	c #2D1412",
"+i	c #311717",
"@i	c #311616",
"#i	c #301616",
"$i	c #D5CED0",
"%i	c #3E2A24",
"&i	c #2A1212",
"*i	c #2F1917",
"=i	c #321A17",
"-i	c #473636",
";i	c #CBC4BD",
">i	c #FCF6E9",
",i	c #FFFDF0",
"'i	c #FFFBEE",
")i	c #C9BDAD",
"!i	c #382923",
"~i	c #3B2D25",
"{i	c #3C2F27",
"]i	c #382B26",
"^i	c #3C2E28",
"/i	c #281918",
"(i	c #271919",
"_i	c #827E7C",
":i	c #E2E1D9",
"<i	c #E6DED7",
"[i	c #FEFBF4",
"}i	c #A18D7E",
"|i	c #2A100E",
"1i	c #200708",
"2i	c #230C0D",
"3i	c #311715",
"4i	c #321716",
"5i	c #B7B3B6",
"6i	c #291210",
"7i	c #2F1816",
"8i	c #351F1B",
"9i	c #371F1B",
"0i	c #321815",
"ai	c #483636",
"bi	c #CEC7BF",
"ci	c #FEF8EA",
"di	c #FEFAEC",
"ei	c #7A6A5D",
"fi	c #34241F",
"gi	c #3A2D26",
"hi	c #41342E",
"ii	c #3D3028",
"ji	c #3C2F29",
"ki	c #2F231D",
"li	c #291A19",
"mi	c #261718",
"ni	c #473B3C",
"oi	c #D0CCC7",
"pi	c #DFDAD3",
"qi	c #FBF7EE",
"ri	c #593F36",
"si	c #1C0506",
"ti	c #240E0E",
"ui	c #321715",
"vi	c #A39A9B",
"wi	c #3E2924",
"xi	c #281110",
"yi	c #301A17",
"zi	c #331B1A",
"Ai	c #341E1A",
"Bi	c #351D19",
"Ci	c #341916",
"Di	c #463434",
"Ei	c #CFCCC5",
"Fi	c #FBF5E7",
"Gi	c #FCF7E8",
"Hi	c #FEF9E9",
"Ii	c #EEE6D6",
"Ji	c #45372F",
"Ki	c #32241E",
"Li	c #3D2E27",
"Mi	c #392B24",
"Ni	c #3D2E29",
"Oi	c #3D2E28",
"Pi	c #372B24",
"Qi	c #2D1F1B",
"Ri	c #241513",
"Si	c #241515",
"Ti	c #312421",
"Ui	c #AAA7A5",
"Vi	c #D7D3D0",
"Wi	c #DACDC0",
"Xi	c #280F0E",
"Yi	c #837B7F",
"Zi	c #3D2823",
"`i	c #2A1111",
" j	c #2B1513",
".j	c #443230",
"+j	c #D1CCC3",
"@j	c #EEE9DD",
"#j	c #F4EFE2",
"$j	c #F9F3E5",
"%j	c #B0A397",
"&j	c #3A2C25",
"*j	c #33251F",
"=j	c #3B2F29",
"-j	c #41332E",
";j	c #44362F",
">j	c #3B2D26",
",j	c #362723",
"'j	c #2A1B18",
")j	c #241715",
"!j	c #2C1E1A",
"~j	c #6A6463",
"{j	c #D7D4D2",
"]j	c #927C6E",
"^j	c #311714",
"/j	c #301515",
"(j	c #685C60",
"_j	c #2B1211",
":j	c #2E1716",
"<j	c #423230",
"[j	c #CCC9C2",
"}j	c #E2DCD3",
"|j	c #ECE7DC",
"1j	c #F3ECE1",
"2j	c #6B5C4F",
"3j	c #32241F",
"4j	c #3F312B",
"5j	c #362824",
"6j	c #2D201B",
"7j	c #2F2220",
"8j	c #3D312F",
"9j	c #CCCAC3",
"0j	c #482C24",
"aj	c #2B1312",
"bj	c #2E1414",
"cj	c #504040",
"dj	c #2B1311",
"ej	c #27100E",
"fj	c #443433",
"gj	c #C1BEB8",
"hj	c #DCD7D0",
"ij	c #E7E3DA",
"jj	c #DBD2C6",
"kj	c #43332C",
"lj	c #342721",
"mj	c #3A2C26",
"nj	c #31221D",
"oj	c #271A17",
"pj	c #2A1C19",
"qj	c #2E1F1C",
"rj	c #6A5B55",
"sj	c #2F1413",
"tj	c #F2F0F2",
"uj	c #3C2B29",
"vj	c #3D2722",
"wj	c #270F0E",
"xj	c #331815",
"yj	c #331915",
"zj	c #463533",
"Aj	c #B8B6B4",
"Bj	c #DDD9D1",
"Cj	c #E4DFD7",
"Dj	c #AA9E92",
"Ej	c #352620",
"Fj	c #3E3129",
"Gj	c #382C26",
"Hj	c #3E312B",
"Ij	c #352823",
"Jj	c #2D1D1B",
"Kj	c #291B1A",
"Lj	c #341F1B",
"Mj	c #2D1312",
"Nj	c #301514",
"Oj	c #2D1514",
"Pj	c #301513",
"Qj	c #2F1414",
"Rj	c #DBDADA",
"Sj	c #250D0D",
"Tj	c #351E1A",
"Uj	c #433231",
"Vj	c #B4B2AE",
"Wj	c #DAD8D2",
"Xj	c #E1DFD8",
"Yj	c #6B5D53",
"Zj	c #3D3129",
"`j	c #2E201A",
" k	c #382A23",
".k	c #3A2C27",
"+k	c #372A25",
"@k	c #30231E",
"#k	c #342720",
"$k	c #2A1D19",
"%k	c #301714",
"&k	c #2F1515",
"*k	c #C0BBBE",
"=k	c #2C1311",
"-k	c #260E0D",
";k	c #433230",
">k	c #ADADAB",
",k	c #D9D6D1",
"'k	c #D5D2C9",
")k	c #382821",
"!k	c #33261F",
"~k	c #3F332D",
"{k	c #31231F",
"]k	c #2F1F1D",
"^k	c #2D1C19",
"/k	c #321615",
"(k	c #2D1512",
"_k	c #9F9898",
":k	c #3B2420",
"<k	c #2C1310",
"[k	c #341B17",
"}k	c #412F2E",
"|k	c #A6A4A1",
"1k	c #D4D3CF",
"2k	c #9D9288",
"3k	c #3D312C",
"4k	c #352723",
"5k	c #32251F",
"6k	c #2B1210",
"7k	c #2B1212",
"8k	c #2D1313",
"9k	c #2E1313",
"0k	c #7B716F",
"ak	c #280E0E",
"bk	c #2B1411",
"ck	c #412E2C",
"dk	c #A19E9D",
"ek	c #CFD0CB",
"fk	c #5B4E44",
"gk	c #332520",
"hk	c #3B2C28",
"ik	c #42342C",
"jk	c #3A2A24",
"kk	c #31241F",
"lk	c #332620",
"mk	c #2E1E1A",
"nk	c #311615",
". . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . + @ # $ % & * = - ; . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . ",
". . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . > , ' ) ! ~ { ] ^ / ( _ : < . [ } . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . ",
". . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . | 1 2 3 4 5 6 7 8 9 0 a b c d e f g h i j . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . ",
"k k . . k k k . k k . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . l m n o p q r s t u v w x y z A B C w D E F G H I J K L [ . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . ",
". k . . k k . . k . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . M N O P Q R S T U V W X Y Z `  .V X ..X +.@.#.$.%.&.*.=.-.;.>.,.M . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . ",
"k k k k k k k k k k k k k k k . . . . . . . . . . . . . . . . . . . . . . . '.).!.~.{.].^./.(._.:.<.[.}.|.V 1.2.[.3.4.V 5.6.z 7.8.9.0.a.b.c.d.e.f.g.. . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . ",
"k k . k . . . . . k . . . . . . . . . . . . . . . . . . . . . . . . . . . h.i.j.k.l.m.n.o.p.q.W r.V s.t.u.V o.v.u.V w.x.y.z.A.5.B.C.D.E.F.G.H.I.J.K.[ . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . ",
"k k k k k k k k k k k k k k k k k k k k k . . . . . . . . . . . . . . . L.M.N.O.P.Q.R.S.T.U.V.W.X.Y.Y.q.Z.U.`. +.+++5.@+#+$+x.T.%+&+%+*+=+-+;+>+,+'+)+!+. . . . . . . . . . . . . . . . . . . . . . . . . . . . . ",
"~+k k k k k k k k k k k k k k k k k k k . . . . . . . . . . . . . . . {+]+^+/+(+_+:+<+Z.[+}+[+o.|+1+y.2+o.3+n.:.3+Z.4+5+6+7+%+Y.n.8+9+0+y.o.a+b+c+d+e+f+. . . . . . . . . . . . . . . . . . . . . . . . . . . . . ",
"~+~+~+~+~+~+k ~+~+~+k k k k k k k k k k k k k . k . . . . . . . . . g+h+i+j+k+l+m+n+o+X.Z.p+Z.U.X.3+2+Y.2+o+q+$+r+v.s+t+u+v+m.w+x+y+z+A+B+C+D+E+F+G+H+I+J+. . . . . . . . . . . . . . . . . . . . . . . . . . . . ",
"~+~+k k ~+~+k k k k ~+k k k k k k k k k k k . . . . . . . . . . . K+L+M+N+O+P+Q+R+R.S+Y.X.Z.T+[+Y.U+Y.o+U+v+V+o+$+B+2+V W+X+n.z+Y+Z Z+0+`+V  @}..@+@@@#@$@. . . . . . . . . . . . . . . . . . . . . . . . . . . . ",
"~+~+~+~+~+~+~+k ~+~+~+k k k k ~+k k k k k k k k . . . . . . . . %@&@*@=@-@;@>@,@'@)@Y.r.1+U+Y.!@Z.~@{@]@%+m.^@/@m.(@.+q._@X+:@u+<@!@[@}@'@%+S.5.|@O+1@2@3@4@. . . . . . . . . . . . . . . . . . . . . . . . . . . ",
"5@5@5@5@6@5@5@5@5@5@5@~+~+~+5@~+~+~+~+~+~+k k ~+k k k k k . . 7@8@9@0@a@b@c@d@e@_+f@X.U+{@Y.g@h@i@j@B+$+@+k@m.l@y+m@Y.v.3.n@m.o@X+p@q.q@@+r@_@_.W C s@t@u@v@. . . . . . . . . . . . . . . . . . . . . . . . . . . ",
"5@5@~+5@5@5@~+5@5@5@~+~+~+~+~+~+k k ~+~+k k k k k k k k k . k w@x@y@z@A@B@C@D@Q.)@E@F@1+q+g@G@p@H@I@E@%+q@J@K@L@n@z+<@X.o@M@%+S+r@N@O@o@P@m.z+:+Q@R@S@T@U@V@W@. . . . . . . . . . . . . . . . . . . . . . . . . . ",
"5@~+~+~+5@~+~+~+~+5@~+~+~+~+~+k ~+k ~+k k k k k k . . k . . X@Y@Z@`@ #.#+#@###$#%#j@&#*#=#-#-#p@;#>#I@,#$#'#y+8+_@z+X+)#7+!#~#`.{#]#g@^#5+/#(#*+_#P@:#[@<#[#}#. . . . . . . . . . . . . . . . . . . . . . . . . . ",
"~+~+~+~+~+5@~+~+~+~+~+~+~+~+~+~+k k ~+k k k k k k . . . . . |#1#2#3#4#5#6#7#Q.8#9#0#a#b#c#d#e#f#g#h#Y.X.]@n@c@X+,#W+]@i#w.j#k#W+ @/@E@l#m#R n#]@u o#p#x [@q#r#s#. . . . . . . . . . . . . . . . . . . . . . . . . ",
"5@5@~+5@6@5@~+~+5@5@~+~+~+~+~+~+~+k ~+~+~+k k k k k . . k t#u#v#w#x#y#z#A#B#C#:@D#E#F#G#H#I#J#K#L#f#M#N#]@_@R O#W+P#Q#i#R#f@[@6+7+5+S#V T#y+U#o#V#'#+@l+:#W#X#Y#. . . . . . . . . . . . . . . . . . . . . . . . . ",
"Z#6@6@6@6@6@5@5@6@6@5@5@5@5@5@~+~+~+~+5@~+~+~+k k k k k k `# $.$+$@$#$$$%$&$*$=$-$;$>$,$'$)$M#F#!$~${$]$/@^$/$($_$:$<$[$}$P#r.|$^$1$/$ @2$3$4$M@5$8.6$c@7$s@8$9$0$. . . . . . . . . . . . . . . . . . . . . . . . ",
"5@5@~+5@5@5@~+~+5@5@~+~+~+~+~+~+k k k ~+k k k k k k . . a$b$c$d$e$f$.#g$h$i$j$k$l$m$n$o$p$q$r$s$t$u$v$w$x$y$z$A$B$C$G#C#[$C$b#z+D$E$F$_+E@G$H$I$J$K$L$H$l@M$N$O$P$Q$. . . . . . . . . . . . . . . . . . . . . . . ",
"6@5@5@5@5@5@~+~+~+5@~+~+~+~+~+~+~+k ~+~+k k k k k k . . R$S$T$U$V$W$X$Y$Z$`$ %.%+%@%#%$%%%&%*%'$=%-%;%>%,%'%)%!%~%{%]%^%/%C#(%5+_%:%<%F$8#K$[%}%|%1%2%3%Q+4%5%6%7%8%. . . . . . . . . . . . . . . . . . . . . . . ",
"6@6@5@6@6@6@5@5@5@5@5@5@~+5@5@~+~+~+~+~+k k k k k k . !+9%:#0%a%b%c%d%e%f%g%h%i%j%k%l%m%n%o%p%q%r%s%t%u%v%w%x%y%z%A%o%B%C%D%y$E%.$|%.$F%G%H%J$I%J%K%L%M%N%O%P%Q%R%S%. . . . . . . . . . . . . . . . . . . . . . . ",
"6@6@5@6@6@6@5@5@5@5@5@5@~+~+~+k ~+k ~+k k k k k k k k T%U%.$V%W%X%Y%Z%`% &.&+&@&#&$&%&&&*&=&-&;&q%>&q%,&'&)&!&*%~&{&]&o%E#^&/&(&_&c@:&<&[&R+}&|&1&2&3&6$4&5&6&7&8&9&0&. . . . . . . . . . . . . . . . . . . . . . ",
"Z#6@6@6@Z#Z#5@6@6@6@5@5@5@5@5@~+~+~+~+~+~+k k k k k . a&b&c&[&P+d&'%e&f&g&h&i&j&k&l&m&n&o&p&q&r&s&t&u&v&w&x&y&z&A&B&C&D&E&F&/$D@G&R+H&I&c$4&J&K&L&M&5&N&O&P&Q&R&S&T&0&. . . . . . . . . . . . . . . . . . . . . . ",
"Z#6@6@6@6@6@5@5@5@6@5@~+5@5@5@~+k ~+~+k k k k . . . . U&3%V&b%W&X&Y&Z&`& *.*+*@*#*$*%*&***=*-*;*>*,*'*)*v&!*~*{*]*^*/*(*_*:*<*(&[*}*|*F$c@1*D.2*3*4*7&O$5*6*7*U%8*9*0*. . . . . . . . . . . . . . . . . . . . . . ",
"6@5@5@5@5@5@5@~+~+5@~+k ~+k k k k k k k k . k k . . . a*@$1*c&b*c*d*e*f*g*h*i*j*k*l*m*n*o*p*q*r*s*t*u*v*w*x*y*z*A*B*C*D*E*F*G*H*e@I*J*K*K*L*M*N*O*P*Q*R*S*T*U*V*W*X*Y*. . . . . . . . . . . . . . . . . . . . . . ",
"5@5@5@5@5@5@~+~+~+5@~+~+~+k ~+k k k k k k k k . k . Z*`* =.=+=&$@=t%#=$=%=&=*===-=;=>=,='=)=!=~={=]=^=/=(=_=:=<=[=}=|=1=2=3=4=5=R#R#R#P&6=7=P&8=9=0=8=a=b=Q&c=Q%d=e=f=. . . . . . . . . . . . . . . . . . . . . . ",
"g=Z#6@Z#Z#Z#6@6@Z#6@6@5@5@5@5@5@~+~+~+k k k k k . . h=i=j=V%k=l=m=n=o=p=q=r='=s=t=u=v=w=x=y=z=A=B=C=D=E=F=G=H=I=J=K=L=M=N=O=P=,%Q=R=S=T=U=V=U=W=X=Y=Z=`= -.-+-@-#-$-%-. . . . . . . . . . . . . . . . . . . . . . ",
"Z#6@6@6@Z#6@6@5@6@5@5@~+~+~+~+~+~+k k k k . . . . . &-*- ==---;->-,-'-)-!-~-{-]-^-/-(-_-:-<-[-}-|-1-2-3-4-5-6-7-8-9-0-a-b-F=K=c-d-e-f-g-h-i-j-k-l-m-i-n-o-+-k-p-q-r-s-. . . . . . . . . . . . . . . . . . . . . . ",
"6@5@5@6@6@6@5@5@5@5@~+~+~+~+~+k ~+k k k k . . . . . &-t-c$u-v-w-x-y-z-A-B-C-D-E-F-G-H-G-I-J-K-L-M-N-O-P-Q-R-S-T-U-V-W-X-Y-Z-`- ;.;+;@;#;$;%;&;*;=;-;;;>;m-,;';);!;~;{;. . . . . . . . . . . . . . . . . . . . . . ",
"6@5@5@5@5@5@5@~+5@5@5@~+~+~+~+k k . k k . . . . . . . ];^;/;(;_;:;<;[;};|;1;2;3;4;E-5;6;7;8;9;0;a;U-b;c;d;e;f;g;h;i;j;k;l;m;n;o;p;d-H*q;#;r;s;t;u;v;w;x;`=y;z;A;B;C;D;. . . . . . . . . . . . . . . . . . . . . . ",
"6@6@6@6@6@6@5@5@5@5@5@~+~+~+~+k k k k k k . . . . . . E;^;F;G;H;I;J;K;L;M;N;O;P;3;Q;R;S;T;U;V;W;X;Y;Z;`; >.>+>@>#>$>%>&>*>=>->;>>>,>'>e-#;n+)>!>~>{>&;x;]>^>/>(>_>:><>. . . . . . . . . . . . . . . . . . . . . . ",
"Z#Z#6@Z#Z#Z#6@5@6@6@5@5@~+5@~+~+k k k k k k . . . . . [>F;}>v-|>1>2>3>4>5>6>7>8>6>9>6>0>a>b>c>d>e>e>f>g>h>i>j>k>l>m>n>o>p>q>r>s>t>u>v>w>x>y>s;~>~>z>A>B>m-y;^>C>D>:>E>. . . . . . . . . . . . . . . . . . . . . . ",
"Z#6@6@6@6@6@5@5@5@6@5@5@~+~+~+k k k k k . . . . . . . 7@F>G>H>I>J>K>L>M>N>O>P>Q>R>S>T>U>V>W>X>Y>Z>`> ,.,+,@,#,$,%,&,*,=,-,;,>,,,',),!,~,{,],s;!>~>^,/,(,_,:,<,[,},U%|,. . . . . . . . . . . . . . . . . . . . . . ",
"Z#6@6@6@6@6@5@5@5@5@~+~+k ~+~+k k . k . . . . . . . . . 1,2,3,4,5,6,7,8,8,9,T>0,S>a,9>E-b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,,,v,w,x,y,z,A,B,~>C,D,E,o-F,G,H,_>I,J,. . . . . . . . . . . . . . . . . . . . . . ",
"Z#5@5@6@6@6@5@~+5@5@~+~+k ~+k k k . . k . . . . . . . . K,L,M,N,O,P,Q,R,S,T,U,V,W,X,Y,Z,`, '.'+'@'#'$'%'&'*'='-';'>',''')'!'~'{']'^'/'('_':'<'['}'|'1'2'H,[,3'H,4'5'6'. . . . . . . . . . . . . . . . . . . . . . ",
"Z#6@5@6@6@5@5@~+5@5@5@~+k k k k k . . . . . . . . . . . 7'8'9'0'a'b'c'd'e'f'g'h'i'j'k'l'T,m'n'o'p'q'r's't'u'v'w'x'y'z'A'B'C'D'E'F'G'H'I'J'K'L'M'N'O'P'Q'R'S'T'U'V'W'X'. . . . . . . . . . . . . . . . . . . . . . ",
"Z#6@6@6@Z#6@6@5@6@5@~+~+~+~+k k k k k . . . . . . . . . Y'Z'`' ).)+)@)#)$)%)&)*)=)-);)>),)')))!)~){)])^)/)()_):)<)[)})|)1)2)3)4)5)6)7)8)9)0)a)b)c)d)e)f)g)h)i)j)k)l)m). . . . . . . . . . . . . . . . . . . . . . ",
"g=Z#6@6@Z#6@5@5@5@6@5@k ~+k k k k . . . . . . . . . . . !+n)o)p)q)r)s)t)u)v)w)x)y)z)A)B)C)D)E)F)G)H)I)J)K)L)M)N)O)P)Q)R)S)T)U)V)W)X)Y)Z)`) !.!+!@!#!$!T=%!&!*!=!-!;!>!. . . . . . . . . . . . . . . . . . . . . . ",
"6@5@5@5@5@5@~+~+~+5@~+k k k k . . . . . . . . . . . . . . ,!'!)!!!~!{!]!^!/!(!_!:!<![!}!|!1!2!3!4!5!6!7!8!9!0!a!b!c!d!e!f!g!h!i!j!k!l!m!n!o!p!q!r!s!t!u!c)v!w!x!y!z!A!. . . . . . . . . . . . . . . . . . . . . . ",
"6@5@5@5@5@5@~+~+~+5@~+k k k k . . . . . . . . . . . . . . B!C!D!E!F!G!H!I!J!K!L!M!N!O!P!Q!R!S!T!U!V!W!X!Y!Z!`! ~.~+~@~#~$~%~&~*~=~-~;~>~,~'~)~!~~~{~]~^~/~(~_~:~<~[~}~. . . . . . . . . . . . . . . . . . . . . . ",
"6@6@5@5@6@5@5@~+~+~+~+k k k k k . . . . . . . . . . . . . M |~1~2~3~4~5~6~7~8~9~0~a~b~c~d~e~f~g~h~i~j~k~l~m~n~o~p~q~r~s~t~u~v~w~x~y~z~A~B~C~D~E~F~G~H~~~I~J~K~L~M~N~O~. . . . . . . . . . . . . . . . . . . . . . ",
"Z#6@5@6@6@5@5@5@5@5@~+k k k . . . . . . . . . . . . . . . k P~Q~R~S~T~U~V~W~X~Y~Z~`~ {.{+{@{#{${%{&{*{={-{;{>{,{'{){!{~{{{]{v,^{/{({_{:{<{[{}{|{1{2{3{4{5{6{7{8{9{0{a{. . . . . . . . . . . . . . . . . . . . . . ",
"g=6@6@6@6@6@5@5@5@5@~+~+k k k . . . . . . . . . . . . . . . b{c{d{e{f{g{h{i{j{k{l{m{n{l'o{p{q{r{s{t{u{v{w{x{y{z{A{B{C{D{E{F{G{H{I{J{K{A~L{l!M{N{O{P{Q{R{S{T{U{V{W{X{Y{. . . . . . . . . . . . . . . . . . . . . . ",
"6@5@5@5@5@5@~+~+~+~+k k k . k . . . . . . . . . . . . . . . Z{`{ ].]+]@]#]$]%]&]*]=]-];]>],]'])]!]~]{]]]^]/](]_]:]<][]}]|]1]2]3]4]5]6]7]8]9]0]a]b]c]d]e]f]g]h]i]j]k]. . . . . . . . . . . . . . . . . . . . . . . ",
"5@5@~+~+5@5@~+k k k k . . . . . . . . . . . . . . . . . . . l]m]n]o]p]q]r]s]t]u]v]w]x]y]z]A]B]C]D]E]F]G]H]I]J]8)K]L]M]N]O]P]Q]R]S]T]U]6]V]W]X]Y]Z]`] ^.^+^@^#^$^%^&^. . . . . . . . . . . . . . . . . . . . . . . ",
"6@5@5@5@5@5@~+~+~+~+~+. k . . . . . . . . . . . . . . . . . *^=^-^;^>^,^'^)^!^~^{^]^^^/^(^_^:^<^[^}^|^1^2^3^4^5^6^7^8^9^0^a^b^c^d^e^f^g^h^i^j^k^l^m^n^o^p^q^r^s^t^u^. . . . . . . . . . . . . . . . . . . . . . . ",
"6@6@5@5@5@~+~+k ~+~+k . . . . . . . . . . . . . . . . . . . v^w^x^y^z^A^B^C^D^E^F^G^H^I^J^K^L^M^N^O^P^Q^R^S^T^U^V^W^X^Y^Z^`^ /./+/@/#/$/%/&/*/=/-/;/>/,/'/)/!/~/{/]/. . . . . . . . . . . . . . . . . . . . . . . ",
"5@5@~+~+~+~+k k k k k . . . . . . . . . . . . . . . . . . . . ^/// 'm'(/_/:/</[/}/|/1/2/3/4/5/6/7/8/9/;]0/a/b/c/d/e/f/g/h/i/j/k/l/m/n/o/p/q/r/s/t/u/v/w/x/y/z/A/B/. . . . . . . . . . . . . . . . . . . . . . . . ",
"5@5@~+~+~+~+k k k k . . . . . . . . . . . . . . . . . . . . . C/D/E/F/G/H/I/J/c/K/L/M/N/O/P/Q/R/S/T/U/V/W/X/Y/Z/`/I/ (.(+(@(#($(%(&(*(=(-(;(>(,('()(!(~({(](^(/(((. . . . . . . . . . . . . . . . . . . . . . . . ",
"5@~+~+~+~+~+k . k . . . . . . . . . . . . . . . . . . . . . . _(:(<(Y/[(}(y^|(1(2(3(4(5(6(7(8(9(0(a(b(c(d(e(f(g(e(h(i(j(k(l(m(n(o(p(q(r(s(t(u(v(w(x(y(z(A(B(C(D(E(. . . . . . . . . . . . . . . . . . . . . . . . ",
"5@5@5@5@~+~+k k k . . . . . . . . . . . . . . . . . . . . . . F(G(X/f(H(I(m'J(K(L(M(N(O(P(Q(R(S(T(U(V(W(X(Y(Z(`( _Y/._+_@_#(#_$_%_&_*_=_-_;_>_,_'_)_!_~_{_t^]_^_. . . . . . . . . . . . . . . . . . . . . . . . . ",
"5@~+~+~+~+~+k k k . . . . . . . . . . . . . . . . . . . . . . 0&/_Q,(_I(__:_<_[_}_|_1_2_3_4_5_6_7_8_9_0_a_b_c_Z(Y^d_e_f_g_h_i_j_k_l_m_n_o_p_q_r_s_t_u_v_w_x_y_. . . . . . . . . . . . . . . . . . . . . . . . . . ",
"6@~+~+~+~+k k . . k . . . . . . . . . . . . . . . . . . . . . . z_(_A_//X^B_C_D_E_F_G_H_I_J_K_L_M_N_O_P_Q_R_S_T_U_V_W_X_Y_Z_`_ :.:+:@:#:$:%:&:*:=:-:;:>:,:. . . . . . . . . . . . . . . . . . . . . . . . . . . . ",
"5@~+~+k k k k . . . . . . . . . . . . . . . . . . . . . . . . . ':):R,!:!:~:{:]:^:/:(:_:::<:[:}:|:1:2:3:4:5:6:7:8:9:0:a:b:c:d:e:f:g:h:i:j:k:l:m:n:o:p:q:r:. . . . . . . . . . . . . . . . . . . . . . . . . . . . ",
"5@~+~+k k k k . . . . . . . . . . . . . . . . . . . . . . . . . 0&s:t:T^u:v:w:x:y:z:A:B:C:D:E:F:G:H:I:J:K:L:M:N:O:P:Q:R:S:T:U:V:W:X:Y:Z:`: <.<+<@<#<$<%<&<. . . . . . . . . . . . . . . . . . . . . . . . . . . . ",
"5@5@k ~+~+k k . . . . . . . . . . . . . . . . . . . . . . . . . . *<=<-<;<><,<'<)<!<~<{<]<^</<(<_<:<<<[<}<|<1<2<6:3<4<5<6<7<8<9<0<%/a<b<c<d<e<f<g<h<i<j<k<. . . . . . . . . . . . . . . . . . . . . . . . . . . . ",
"5@~+k k k k . . . . . . . . . . . . . . . . . . . . . . . . . . . l<m<n<o<p<q<r<s<t<u<v<w<x<y<z<A<B<C<D<E<F<G<H<I<J<K<L<M<N<O<P<Q<R<S<T<d<U<r_V<W<X<Y<Z<. . . . . . . . . . . . . . . . . . . . . . . . . . . . . ",
"5@~+k k k k . . . . . . . . . . . . . . . . . . . . . . . . . . . `< [.[+[@[#[$[%[&[*[=[-[;[>[,['[)[![~[{[][^[G{/[([_[:[<[[[}[|[1[2[3[4[5[6[7[8[9[0[a[b[. . . . . . . . . . . . . . . . . . . . . . . . . . . . . ",
"~+k k k . . . . . . . . . . . . . . . . . . . . . . . . . . . . . + c[d[e[f[g[h[i[j[k[l[m[n[o[0_p[q[r[s[t[u[Z:v[w[x[y[z[A[>~B[C[D[E[F[G[H[I[J[K[L[M[N[. . . . . . . . . . . . . . . . . . . . . . . . . . . . . . ",
"~+k k k k . . . . . . . . . . . . . . . . . . . . . . . . . . . . . O[P[Q[R[S[T[U[V[W[X[Y[Z[`[ }.}+}@}#}$}d!%}&}*}=}-};}>},}'})}!}~}&/{}]}^}/}(}_}:}<}. . . . . . . . . . . . . . . . . . . . . . . . . . . . . . ",
"~+k k k k . . . . . . . . . . . . . . . . . . . . . . . . . . . . . [}}}|}1}2}3}4}5}6}7}8}9}0}a}b}c}d}e}f}g}h}i}j}k}l}m}n}o}E[p}q}r}s}t}u}v}w}x}y}z}A}. . . . . . . . . . . . . . . . . . . . . . . . . . . . . . ",
"~+k k k k . . . . . . . . . . . . . . . . . . . . . . . . . . . . . B}C}D}E}F}G}H}I}J}K}L}M}N}O}P}Q}R}S}T}U}V}W}X}Y}Z}`} |.|+|@|#|V)>($|%|&|*|=|-|;|>|. . . . . . . . . . . . . . . . . . . . . . . . . . . . . . ",
"~+k k . . k . . . . . . . . . . . . . . . . . . . . . . . . . . . . l ,|'|)|!|~|{|]|^|/|(|_|:|<|[|}|||1|2|3|4|5|6|7|8|9|0|a|b|c|d|e|f|g|h|i|j|k|l|m|n|. . . . . . . . . . . . . . . . . . . . . . . . . . . . . . ",
"~+k k k . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . o|p|q|r|s|t|u|v|w|x|y|z|A|B|C|D|E|F|G|H|I|J|K|L|M|N|O|P|Q|R|S|T|U|V|W|X|Y|Z|`| 1. . . . . . . . . . . . . . . . . . . . . . . . . . . . . . ",
"~+k k k k . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . .1+1@1#1$1%1&1*1=1-1;1>1,1'1)1!1~1{1]1^1/1(1_1:1<1[1}1|1112131415161718191^[01a1b1. . . . . . . . . . . . . . . . . . . . . . . . . . . . . ",
"~+k k k . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . M c1d1e1f1g1h1i1j1k1l1m1n1o1p1{1q1r1s1t1u1v1w1L|x1y1&~z1A1B1C1D1E1F1G1H1I1J1K1L1M1N1J . . . . . . . . . . . . . . . . . . . . . . . . . . . ",
"~+k k k . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . O1P1Q1R1S1T1U1V1W1X1Y1Z1`1 2.2+2@2#2$2%2&2*2=2-2;2>2,2'2)2!2~2{2]2^2/2(2R<_2:2<2[2}2|2. . . . . . . . . . . . . . . . . . . . . . . . . . ",
"~+k . k k k . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 0&12223242526272829202a2b2c2d2e2f2g2h2i2j2k2l2m2n2o2p2q2r2s2t2u2v2w2x2;~y2z2A2B2C2D2E2F2. . . . . . . . . . . . . . . . . . . . . . . . . ",
"k k k k . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . G2H2I2J2K2L2M2N2O2P2Q2R_R2S2T2U2V2W2X2Y2Z2p2`2 3.3+3@3#3$3%3&3*3=3-3;3>3,3'3)3!3~3{3]3. . . . . . . . . . . . . . . . . . . . . . . . . ",
"~+k k k . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . ^3/3(3_3:3<3[3}3|313233343x~536373839303a3b3c3d3e3f3g3h3i3j3k3l3,}m3n3o3p3q3r3s3t3u3v3. . . . . . . . . . . . . . . . . . . . . . . . ",
"~+k . k . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . w3x3y3z3A3B3C3D3~']'E3F3G3H3I3J3K3L3M3N3O3P3Q3R3S3T3b|U3V3W3X3;~Y3Z3`3 4.4+4@4#4$4%4&4*4. . . . . . . . . . . . . . . . . . . . . . . ",
"~+k . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . =4-4;4>4,4'4)4!4~4{4]4^4/4(4_4:4<4[4}4|4S314243444546474849404a4b4c4d4e4f4g4h4i4j4k4l4m4. . . . . . . . . . . . . . . . . . . . . . ",
"k . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . n4o4p4q4r4s4t4u4v4w4x4y4z4A4B4C4D4E4F4G4H4I4J4K4L4M4N4`}O4P4Q4R4S4T4U4V4W4X4Y4Z4$4{3`4 5. . . . . . . . . . . . . . . . . . . . . ",
"k k . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . .5+5@5#5$5%5r&&5*5=5-5;5e%>5,5v'I!'5)5!5~5{5]5^5/5(5_5:{:5<5p}[5}5|5V4152535455565758595. . . . . . . . . . . . . . . . . . . . ",
"k k . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 05a5b5c5d5o%c*e5f5g5h5i5j5k5l5m5n5R<!'b4o5p5h^q5r5K{(584s5t5u5v5w5x5y5z5A5B5C5D5E5F5G5H5I5J5. . . . . . . . . . . . . . . . . . ",
"k k . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 0&K5L5M5N5O5P5Q5R5S5T5U5V5W5X5Y5Z5`5 6.6+6@6Q4#6,}_{84({$6%6&6*6=6-6;6>6,6'6)6!635~6{6]6^6/6(6_6E(. . . . . . . . . . . . . . . ",
"k . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . :6<6[6}6|616263646566676869606a6b6c6d6e6f6g6,}h6Y343i6j6k6l6m6~+n6-6o6p6q6r6s6s6'6t6u655v6w6x6y6z6A6B6C6. . . . . . . . . . . . ",
"k . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . D6E6F6G6H6I6J6K6L6M6N6O6P6Q6R63!S6T6U6V6W6X62[Y6Z6`6 743$6.7+7@7#7k 5@=6$7%7&7*7*7r6=7-7;7B5>7,7'7)7!7~7{7]7^7/7(7_7. . . . . . . . . ",
"k . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . & :7<7[7}7|717273747576777879707a7b7c7d7e7f7g7h7i7j7g:Y60<k7+7l7m7n7o7. ~+5@p7q7r7s7t7t7t7u7r6-7v7;735w7x7y7,7z7A765B7C7D7E7F7G7+ . . . . . ",
"k . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . !+H7I7J7K7L7M7N7O7P7Q7R7S7T7U7V7W7X7Y7Z7`7 8.8+8@8#8$8%8&8f6h6/5*8=8I1-8;8. k k v^>8,8s7'8'8)8s7!8~8r6=7v7'6h)w7x7u6{8]8^8/8(865_8:8<8[8}8|8!+. . ",
"k . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 18283848586878683{889808a8~+b8c8d8e8f8g8h8i8j8k8l8m8n8o8p8[5.6q8r8s8x2I1t8u8. k ~+~+v8w8x8y8z8A8B8z8)8!8u7r6*7C8D8E8'6B535F8{8]8G8H8v6I8J8K8L8M8N8O8P8",
"k k . . . . . . . . . . . . . . . . . . . . . . . . . Q8R8S8T8U8V8W8X8Y8Z8P7`8 9.9+9@95@g.#9$9%9&9*9=9%3-9d{34;9>9,9'9)9!9~9}[{9]9^9E(k k ~+~+~+/9(9_9:9<9<9[9:9_9z8)8s7}9|9D8u7r6-7;7B5192939G849596979899909a9b9",
"k k . . . . . . . . . . . . . . . . . . . . . . . c9d9e9f9Q{68g9h9i9j9k9+9l9m9l9n9o9p9~+k q9r9s9t9u9v9w9W7x9y9x9z9A9B9.6C9D9E9!5F9!+k k k k k k G9H9:9I9I9J9K9L9L9M9N9O9}9}9P9B8t7Q9r6'6R9S9T9U96~V9V9W9X9Y9Z9`9 0",
". . . . . . . . . . . . . . . . . . . . . . .0+0@0#0$0%0^~&0*0=0-0;0>0,0'0)0!0+9~0~0{0k k . ]0^0/0(0_0:0<0[0}0|01020304050)}6070k k ~+~+~+~+~+v^809000a0a0b0c0y8d0e0y8s7s7s7f0K9:9A8*7g0h0i0j0k029P{T9U'l0m0n0o0p0",
"k k . . . . . . . . . . . . . . . . . ;8q0r0s0t0u0r7&0v0Y8w0;0;0;0x0i9~0~0W8o9y0i9z0A0~+k . k B0C0D0E0F0G0H0I0J0K0L0M0N0O|O0P0k ~+~+5@6@5@5@Y{Q0R0J9a0a0S0T0U0d0L9y8y8M9V0L9W0X0:9Y0O9q6g0Z0`0 a.ai0 a+a+aS9@a#a$a",
"k k . . . . . . . . . . . . . . . %a&a*a=a-a;a78X8=0w0>aw0;0x0,a'a)a!aY8!a~aY8!a!a{a]ak k . . . ^a/a(a_a:ak|x)'^<a[a}a|a1a2ak k k ~+~+5@5@v^3a4a5a6a7ab08a8ab09ad0d00aaaV0S0W0L9baM9caO9g0daeag0h0fah0`0h0ga.a aS9",
"k . . . . . . . . . . . . . . haiajaU8kalau!ma>a>anaoax0paqa'arasatanauava!awauaxayazak . . . . + AaBaCaDaEaJ4!510FaGaHa!+k k k k k ~+5@5@IaJaKa6a9aLab0MaNaOaPa8ab0QaV0Raa0Sa0a0aaa0aTaTae0UaO9VaWa&7Vag0XaYaZa`a",
"k . . . . . . . . . . . . 7@ bY@U8;a.b+b@b#b#btapa$b$b%bsa&b*b=brarax0-bw0;0;b>b,b'b)b~+k k . . . . !b~bI'{b]b^b/b(b_bk k k k k k k 5@6@:b<b[b}bb0b0|bMab01b2b7a1b3b4b5b6b7b8bd00aL9aa0aM9e0Rae0TaUa}99b9b*70b0b0b",
"k . . . . . . . . . . . abbbcbdb.b$!eb#!fb$bgb$b$bqasa%b&bhbibjbkbkbra'alb;b-bmb;bnbobk . . . . . . . pbqbrb.6sbtbub. . . . . . . k ~+v^Iavbwb+9|bxbybMa2b1bb08azb6b*b6bAbBbCb6ahb0ahbQahb0ae00ay8aae0TaTaDbEbFbGb",
". . . . . . . . . . HbIbJbKbLb*0#bfbMbNbMbUaNbNbObAbibPbPbQbRbsarakbsaSbTbx0)a>b>bUbVbk . . . . . . . WbXbYbZb`bk . . . . . . . k k ~+Y{ c.c+c@cxb#c#cOa#c1b1b3b4b$c$chb%c&c7bOa3bd0b0d03b0a0aU0d0d00a*ce0TaDbTaTa",
". . . . . . . . . =c-c;c>cO'+b,cfbMbMb'c%b'cV0Ab%b*b*b%c)czb!c~crasa{c=bsara)ara]c^c/c~+. . . . . . (c_c:c<c[c}c. . . . . . k k k ~+~+|c1c2c3czb1bOa4c#c#cxb1b)czbLaQbzb|b5c6c7ayb6a8aU0S0U03bU0S0U0S0b0T0T07cT0y8",
"k . . . . . . 8c9c0cacbcu!ccfbMbUa'c'cV0V0hbRbibhb4b!c%cibQb&b!c4bibdcsa&bsasaec{cfcgck . . . . . hc(.a+icjckclcmc. . . . . . k k k ~+ubncoc3bpcMa#c#cOaMaOazbzbpcqczb1bpcrc7b#cOaOa8a8a8a8a8a8asc8ab0b0d0aa0aT0tc",
". . . . . . ucvcwc.b7~+b,cgbfbNbV0V0Rb0ae0hbhbhbRb*b!c!cQbib!cxc)c%c!csaxc!csara4byczcv^k . . . Ac89BcCcDcEc5'FcGc. . . . . . k k k ~+HcIcJchb@cxbKc|bLcpcpcpcpcMcpcNcpcLcOcBbOa2bOaOa2ba02b7a2bybOa6a6ab0d0La3bd0",
". . . . . > P$Pcu!QcRcScgbMbdaMb'cRbhbPb0a0ahb4bAb*bTczb!c%cUcUc)cQbUcxc26!cVcxc4bWcXcYc. . . Zc`c d.d+d@d#d]6$d%d&d. . . . . . . . ~+*d=d-ddc|bLcOa1bpc|bpcpc;d;d>d,d>d>d'dBb)d!d~d4cOa4c4c{d{d]d^d7a7aMa3bLaLaNa",
"k . . . . /d(du!#bNb_dMb'c'cRaObV0['0a3bzbzbPb4bQbib:dPb!c%cibUcQb)c4bPb)c4bQbqc<d[d}d*^k . . |d1d2d3d4d5d6d7d8d@d9da$. . . . . . . k 0dad*bdc|bLcLc#cqcNcpcMcNc,dpcbd,dcd'ddded{,fd~dKc)d)d!d!d!d4c8axb@cT0gdd06b",
". . . . hdid#!N'N9N9'cN9jd_dOb'cjdRbPb3bQakdpczbzbkd,dldxcxcTcUcUcUc%cUczbQbpc)cxcmdnd>8k . odpdqdrdsdtdudvd@dwdxdydzd. . . . . . . . AdBdqc%cxb;dLcxbLcMcpcbdbdcdLccdCdcdDdEdKcFdGdHdfdGd)d)dedfd2bMazb3b3bLaLa4b",
". . . . Idu!Jd['aaKde0N9RbRa%bN9jdRbhbqcPb1bkdpczb1bQbzbQbUcUcQb:dLdqc)c1bpcbd)cxcMdNdOd. . PdQdRdSdTdUdVdWdXdCcYdZd`d e. . . . . . . .erapczbMcLcLcNcbd,d;d+e,dNc@e#ccdKc#e$eFd%eGd&e)dEd&e%e)d!dOaOa1bxb1b|b|bzb",
". . . . *e,cN'aaKdba=eba-eOb%b'c%bRbQbPbkdqc1bLc;eqc1bMc)czbqcMcldLdLdqcLcbd>dzbxc>e,e'e. 0&)e!e~e{e]e^e/e~;(e_e:e<e[e}e|e. . . . . 1e2eec:d;e|bMcpcpc;d+e>d@ebdNcNccdbd3eDd4e&e5e%e6e6e7e6eGdFdFd4cOa1b#cxbLcxbCd",
". . . W@8e_dMb9e9e0e0e0a'c%bV0%b%bPbibPb,d,daeKcqc)czbqcLdQbpcLdLdpcbeLcOa>dqcLdQbcedeee. fegeheiejekelemener-oe5'rdpeqere. . . . . sete!c)cKcLcNcLcLcLcueNcLc3ecdcd3ebdvewexeyeze5eAeAeBeAeCe4cKcaeOapcLcxb;dLcCd",
". . . DeEejd%bFe0eGe0aPb['['%b%bibRbUcPb1b1b!d6eLc,d>dpcldMcMc)cpc,d>dcdLcpc>dqc)cHeIeJe+ Ke!eLeMeNeOevdC7S*S*Pexd]eQeReSeTe. . . UeVeWeUc4bLdfd;dueNcNc@eNcLccdXeYeKcZeXe`e fS5ze.f+fAe+f6eFdKcKcKccdKc#c#cLc#cxb",
". . . @f#fKd['GescU0aa['jdib&bibib4bQbqcqc>d{,$fAeLcNcpcLdLdLdMcpccded,dLcbdLcNcLd%f&f*f=f-f;f>f,f'f)f!f~f{f]fsdD>T'=;^f/f(f_f. . :f<fdcUc)cLdLcLcMcpc>dLcNcMcuecdcdveFdFdwe[f+f.f}f}f}f+f%e)dveve{,KcaeveKc#c|f;d",
". . . 1f2f3faab08ascc03bRbibib!cQbQbqcqc,dbdKced$eEdCd4fMc>d>d>d3eveKcae;e>d>dNc>d5f6f7f8fMe9f0fafbfcfdfefffgfhfifjfkflfmfnfof. Uepf%c)cLdqczbld4c>dcdqfKcNc>d>dXecd3eveverfsf$e}ftfufvfwf6eFdT5Fd)d4cKcFdxfKcCdcd",
". . . yfTbzfAf6aBf8a6aQaCfjdDfDf26Pb,d1bbdLcve%eBeEfKcbdue>dLcj5T5bdbdKcbdbdaeKcNcHeFfGfHfIfJfKfLfMfNfOf7dPfq-QfRfB>]>SfTfUfVfWfXfYfQbqcqcPbLdMcLcCdbdcdKcKccdZeKcbdveKcT5Zf`fuf gZf}f.gwfFdveFdFdFdedKcHdFdvexf+g",
". . . @gta#g$gBfBfsc8ascQaRbDf26UcPbkd,dLcKcFded+fEf$fbd>dcd%gxfbd3eT5bd@e&gU5bd>d*g=g-g;g>g,g'g)g!g~g{gW*]gcf^g/g(g_g:g<g[g}g|g1gLdqcLcNcLdLdLdLd~d#ccdcdT5T5cd{,3e3eve2g3g4gDd5gZf6g5eedveKc#c)dcd)dedHdedvecd~d",
". . 7g8gRaBb9g6aBf$g$gscRbRb&b26QbLdqcNcbdLcFded+ftf0gT5bdFdj52gXeveFd3e3eT53ebd>dagbgcgXf% dgeg'efgQ&Ud9=gghgigZ jgkglgmgngogpgqg)cxbcdOa>dNcLd+ebdFdKcT5Kcvevecdvecdj5rgsgtgDduguf.gze%evevgve%gFd%g%g%e5e%eHdxf",
". . wgxg0aygzgBfAg2bAgsc26ibDfCfUcQbLd>dOabd%g%g%eBgufCgDgFdvej5FdEgFgT5FdGgT5aeKcHgIgJgKgKgLgMgNgOgPgQgRgSgTg/.:,UgVgWgXgYgZg`g h1bNccdNc>dLdLd>d>d%gcdve.hT5+hve{,@h#h$h%h&h g*h3gwf5e%e%eve%g%g%eed%e5e6e%g5evg",
". . =hO'aaGdBe!dzf-h!dqcRbDf~c26Qb;h,d>daebdFd5e5e+fufuf%gFd%gveveFgFgj5Fd4c3ecd4c>h,hd.'h$ )h!h~h{h.-Vdje]h(8^h/h(h_h:h}g<h[h}hOabdLcbdcdbd>dbeNcNcCd|hveve3e%gj5zerf1h2h3h g*h}f.fed+hve%g@h%g%gGd%e%e5ezeze4h@h",
". Q$5hu!kd6h7hx>6h6h2bscPb2626QbLdpc,d8hT5KcFgFg%gwf.fFgFg+h%gve%gDgHdveFg3eT5T5T59h0hahbhchdhehfhghhhTdihjhkhlhmhnhohphqhrhshthbdKc@evebd@eLc@ebd>d.hzeHdFgvezeuh$hvhwhxhZf*hyhzhzeS5Dg@hvgHded@h5eedwfAezhzhAhAh",
". BhCh(dsc6hDh&e7e6h!dkdQaPbPbEh;h;hbdbd@e3eed%g%g%e%gFgDgzeFg%g%gS5+hj5%gFgvevecdFhGhHhIhIhJhKhLhMhp~NhOhPh5'QhRhShThUhVhWhXh<dKcKc@ecd{,Nc@ecdYhbdbdbdAeS5ze`eZh`h i.i3g3g}f3g5ezezeveze%e5e5e+iwf5eAh@i#izh+i+i",
". $i%i#b6a7e&i7e*i6h]dkdEhPbQbqc>d>dLcbd3eFdj5+hze%g%gFgS5%g%gj5j5%e%eFgEg%g=iFdve-i;i>i,i,i'i)i!i~i{i]i^i/eTd#-/i(i_i:i<i[i}iKc{,cdveveKcbdbdcdKc3e3exfS5.f|i1i2iDdtftf.f3i.fze%eze%e%gze4iCeS5wf4izh5eze3iwf.gzh",
". 5iLbgb8a7e6i7i7iEd9g8iPbEhTc9iqc>dLccd3eveHdveFgFgFdFdj5%g+h%g%g0iDgzeS5Fg%eT52gaibici'idi'ieifigi]ghiiiS*jikiliminioipiqiribdT5XeT5j5bdveKcKcFdFgveFdve.isitiDd6g.g.f4ize|hzeze%e@hDgze5ezhwfAe.f.g.f6g.gui@izh",
". viwiN'BfEdxiEf7iyiziAiqcPbEh,dqcBiLc@e3eve%e%e%g%g%e%ej5%gDg4hDgCiDg%gze5eFgS5=iDiEiFiGiHiIiJiKiLiMiNiNiOiPiQiRiSiTiUiViWi3e3eFdveveveKc~dFdveveT5ve%gXe%gXiDd6gzeuiwfwfze5eze%g%e4h%ewf6eAh.fAewfAeAe.gAezh.gwf",
". YiZifb!dEd`i j+fEd;e,dkdPbqckd.hbdbdbdj5FgFgze%gDg%g%e%g%gzeDgDgS5ze0iui@h%e%eFg.j+j@j#j$j%j&j*jB;=j-j;j>j,jn-'j)j!j~j{j]jve%gve%gedHdve4cFdveFdj5HdT53eve3gDd3iwfze0i3i6eS5wfze6e6eze^jwf.fuh}f}f}fAe/j.g.g/j3i",
". (j2fNb7b+f_j6i:jEdOa;eqcPbUcqcaebd3eveT5FdDgDg%eS5Dg%g%g%g%g4hzeS50i4hzezeDgFg%e<j[j}j|j1j2j!#3jB;giji]f4j5j6j[.z>7j8j9j0j%gHdj5veve+h%g%gveFd%gT5Fdj5XeZeHdaj.f3izeze5e5e.f3ize%ezhze.gwf4iufZfbjyh}fyh}f.g.g6g",
"7@cjv0'cGd4edjej$e%e8hAikdEhPbkdkdaeFgT5%g%g%g%g+h%e4hDgzeze0ize4hze^jwfzeze%gj5%efjgjhjijjjkjljmjR*~gPhCcNhljnj'jojpjqjrj%e%ej55e%gxfvgFdFdve%g%g%gj5Hd2gT5j5.g g.fze|hzezezh.f|h3izewf}f}f+fZfZfyh gtfyhtf6gsjZf",
"tjujvjjd6hBeajwjBe)daeaekdPbQb,dBiFgS5KcHdj5=i%gDg%gzewf4hxj%e0i0iyjyeui3i^jye%ezezjAjBjCjDjEjR.<ejiFjjiGjHj%.IjJjKjRh';Ljze0i%gze%gwf4hveve%gHd%e{,ve3ecdS5Fg%eMjyhwf|hwf0iwfwf%e4iwfwfNj.fyhOjZftfuf6gPjtf/jbjQj",
"Rjw0-0QaGd+fDdSjBe-h;e;eTjqcqcqc,d%eS5Fd%g%gFg%g4h4hwf4hzezeS50iDg4h0i3g0ize0i5eS5UjVjWjXjYjZj`jmj k>j.k+k+k+-@k#kQi$k(.=i%ezhFd%ezeHd)dveveFgj5HdYevecdcdFd%gFg%kaj3g%k3iwfwf%gS53i.g.gtf.g&kvf gZfZf}fyhyhyhtf}f",
"*kTbcc$gddCg=k-kCg)d)d4cqcQb8i9iaeDg3i=i%eDgFgDg%eze4hS54hzezeyjS50i0i|hui3iS5zeS5;k>k,k'k)kL%w !k~kMiihp-ke!;Mh{k]k^k4+%gzewfze%e%g%g%e@h%gvgj5vecdZeT5ve%g%e%gzeMjMj^jzeS5wf3i5e/k6g}ftfyhZf&kZf gDdZfMj(kZfsjNj",
"_k:k'c6hBe6g<k-kOc=iGdT5,dqcqc,d[kFg.f|hFgS5ze%g%gzeDg4h4ize0i0iS5wfze^j3i|hwf4hS5}k|k1k2kt S.Sd3j]g.-^e3k4k3j5k+k4k>;-hze%ezeDgze%g%g+hFdedHdve3e3e%gj5ve%gDg%gEg6g6kvf3i3iwf3i|h}fyhtf g.i7k.iMjMjDdZfZf8kZf9ktf",
"0knaU07eBgCgajakbk$fGd9gbdqcqcKcFgDgze6gS5j5ze+hDgze3i3i4h|h^jui0i3i0i0izezezh|h|hckdkekfk!jj#B;gk]ihkikjka=gkkklkhgmkwf0i.fwfzeze%g4h%g5e4h%gve2gzeFgj5=iT5%g%g5eze5gdjuh3ink4iAe+f3gvfDdMjxh g g=kMjsgMj8kZf9kvf"};/*}}}*/

AboutDialog::AboutDialog(QWidget *parent): QDialog(parent, NULL, true)/*{{{*/
{
	setMinimumSize(300, 180);
	QBoxLayout *l1 = new QVBoxLayout(this, 10);
	QLabel *info = new QLabel("<b>VyQChat v" + QString(VYQCHAT_VERSION)
			+ "</b><br>by "
			"Pawel Stolowski<br>&lt yogin@linux.bydg.org&gt <br>"
			"http://linux.bydg.org/~yogin", this);
	info->setAlignment(AlignCenter);
	QLabel *foto = new QLabel(this);
			
	QPixmap *pfoto = new QPixmap((const char **)foto_xpm);
	foto->setPixmap(*pfoto);
	foto->setAlignment(AlignCenter);

	QPushButton *b_ok = new QPushButton("OK", this);
	l1->addWidget(info);
	l1->addWidget(foto);
	l1->addWidget(b_ok);

	connect(b_ok, SIGNAL(clicked()), this, SLOT(close()));
}/*}}}*/

AboutDialog::~AboutDialog()/*{{{*/
{
}/*}}}*/

